'''OpenGL extension NV.texture_shader

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_texture_shader'
_DEPRECATED = False
GL_OFFSET_TEXTURE_RECTANGLE_NV = constant.Constant( 'GL_OFFSET_TEXTURE_RECTANGLE_NV', 0x864C )
GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV = constant.Constant( 'GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV', 0x864D )
GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV = constant.Constant( 'GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV', 0x864E )
GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV = constant.Constant( 'GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV', 0x86D9 )
GL_UNSIGNED_INT_S8_S8_8_8_NV = constant.Constant( 'GL_UNSIGNED_INT_S8_S8_8_8_NV', 0x86DA )
GL_UNSIGNED_INT_8_8_S8_S8_REV_NV = constant.Constant( 'GL_UNSIGNED_INT_8_8_S8_S8_REV_NV', 0x86DB )
GL_DSDT_MAG_INTENSITY_NV = constant.Constant( 'GL_DSDT_MAG_INTENSITY_NV', 0x86DC )
GL_SHADER_CONSISTENT_NV = constant.Constant( 'GL_SHADER_CONSISTENT_NV', 0x86DD )
GL_TEXTURE_SHADER_NV = constant.Constant( 'GL_TEXTURE_SHADER_NV', 0x86DE )
glget.addGLGetConstant( GL_TEXTURE_SHADER_NV, (1,) )
GL_SHADER_OPERATION_NV = constant.Constant( 'GL_SHADER_OPERATION_NV', 0x86DF )
GL_CULL_MODES_NV = constant.Constant( 'GL_CULL_MODES_NV', 0x86E0 )
GL_OFFSET_TEXTURE_MATRIX_NV = constant.Constant( 'GL_OFFSET_TEXTURE_MATRIX_NV', 0x86E1 )
GL_OFFSET_TEXTURE_SCALE_NV = constant.Constant( 'GL_OFFSET_TEXTURE_SCALE_NV', 0x86E2 )
GL_OFFSET_TEXTURE_BIAS_NV = constant.Constant( 'GL_OFFSET_TEXTURE_BIAS_NV', 0x86E3 )
GL_PREVIOUS_TEXTURE_INPUT_NV = constant.Constant( 'GL_PREVIOUS_TEXTURE_INPUT_NV', 0x86E4 )
GL_CONST_EYE_NV = constant.Constant( 'GL_CONST_EYE_NV', 0x86E5 )
GL_PASS_THROUGH_NV = constant.Constant( 'GL_PASS_THROUGH_NV', 0x86E6 )
GL_CULL_FRAGMENT_NV = constant.Constant( 'GL_CULL_FRAGMENT_NV', 0x86E7 )
GL_OFFSET_TEXTURE_2D_NV = constant.Constant( 'GL_OFFSET_TEXTURE_2D_NV', 0x86E8 )
GL_DEPENDENT_AR_TEXTURE_2D_NV = constant.Constant( 'GL_DEPENDENT_AR_TEXTURE_2D_NV', 0x86E9 )
GL_DEPENDENT_GB_TEXTURE_2D_NV = constant.Constant( 'GL_DEPENDENT_GB_TEXTURE_2D_NV', 0x86EA )
GL_DOT_PRODUCT_NV = constant.Constant( 'GL_DOT_PRODUCT_NV', 0x86EC )
GL_DOT_PRODUCT_DEPTH_REPLACE_NV = constant.Constant( 'GL_DOT_PRODUCT_DEPTH_REPLACE_NV', 0x86ED )
GL_DOT_PRODUCT_TEXTURE_2D_NV = constant.Constant( 'GL_DOT_PRODUCT_TEXTURE_2D_NV', 0x86EE )
GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV = constant.Constant( 'GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV', 0x86F0 )
GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV = constant.Constant( 'GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV', 0x86F1 )
GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV = constant.Constant( 'GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV', 0x86F2 )
GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV = constant.Constant( 'GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV', 0x86F3 )
GL_HILO_NV = constant.Constant( 'GL_HILO_NV', 0x86F4 )
GL_DSDT_NV = constant.Constant( 'GL_DSDT_NV', 0x86F5 )
GL_DSDT_MAG_NV = constant.Constant( 'GL_DSDT_MAG_NV', 0x86F6 )
GL_DSDT_MAG_VIB_NV = constant.Constant( 'GL_DSDT_MAG_VIB_NV', 0x86F7 )
GL_HILO16_NV = constant.Constant( 'GL_HILO16_NV', 0x86F8 )
GL_SIGNED_HILO_NV = constant.Constant( 'GL_SIGNED_HILO_NV', 0x86F9 )
GL_SIGNED_HILO16_NV = constant.Constant( 'GL_SIGNED_HILO16_NV', 0x86FA )
GL_SIGNED_RGBA_NV = constant.Constant( 'GL_SIGNED_RGBA_NV', 0x86FB )
GL_SIGNED_RGBA8_NV = constant.Constant( 'GL_SIGNED_RGBA8_NV', 0x86FC )
GL_SIGNED_RGB_NV = constant.Constant( 'GL_SIGNED_RGB_NV', 0x86FE )
GL_SIGNED_RGB8_NV = constant.Constant( 'GL_SIGNED_RGB8_NV', 0x86FF )
GL_SIGNED_LUMINANCE_NV = constant.Constant( 'GL_SIGNED_LUMINANCE_NV', 0x8701 )
GL_SIGNED_LUMINANCE8_NV = constant.Constant( 'GL_SIGNED_LUMINANCE8_NV', 0x8702 )
GL_SIGNED_LUMINANCE_ALPHA_NV = constant.Constant( 'GL_SIGNED_LUMINANCE_ALPHA_NV', 0x8703 )
GL_SIGNED_LUMINANCE8_ALPHA8_NV = constant.Constant( 'GL_SIGNED_LUMINANCE8_ALPHA8_NV', 0x8704 )
GL_SIGNED_ALPHA_NV = constant.Constant( 'GL_SIGNED_ALPHA_NV', 0x8705 )
GL_SIGNED_ALPHA8_NV = constant.Constant( 'GL_SIGNED_ALPHA8_NV', 0x8706 )
GL_SIGNED_INTENSITY_NV = constant.Constant( 'GL_SIGNED_INTENSITY_NV', 0x8707 )
GL_SIGNED_INTENSITY8_NV = constant.Constant( 'GL_SIGNED_INTENSITY8_NV', 0x8708 )
GL_DSDT8_NV = constant.Constant( 'GL_DSDT8_NV', 0x8709 )
GL_DSDT8_MAG8_NV = constant.Constant( 'GL_DSDT8_MAG8_NV', 0x870A )
GL_DSDT8_MAG8_INTENSITY8_NV = constant.Constant( 'GL_DSDT8_MAG8_INTENSITY8_NV', 0x870B )
GL_SIGNED_RGB_UNSIGNED_ALPHA_NV = constant.Constant( 'GL_SIGNED_RGB_UNSIGNED_ALPHA_NV', 0x870C )
GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV = constant.Constant( 'GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV', 0x870D )
GL_HI_SCALE_NV = constant.Constant( 'GL_HI_SCALE_NV', 0x870E )
glget.addGLGetConstant( GL_HI_SCALE_NV, (1,) )
GL_LO_SCALE_NV = constant.Constant( 'GL_LO_SCALE_NV', 0x870F )
glget.addGLGetConstant( GL_LO_SCALE_NV, (1,) )
GL_DS_SCALE_NV = constant.Constant( 'GL_DS_SCALE_NV', 0x8710 )
glget.addGLGetConstant( GL_DS_SCALE_NV, (1,) )
GL_DT_SCALE_NV = constant.Constant( 'GL_DT_SCALE_NV', 0x8711 )
glget.addGLGetConstant( GL_DT_SCALE_NV, (1,) )
GL_MAGNITUDE_SCALE_NV = constant.Constant( 'GL_MAGNITUDE_SCALE_NV', 0x8712 )
glget.addGLGetConstant( GL_MAGNITUDE_SCALE_NV, (1,) )
GL_VIBRANCE_SCALE_NV = constant.Constant( 'GL_VIBRANCE_SCALE_NV', 0x8713 )
glget.addGLGetConstant( GL_VIBRANCE_SCALE_NV, (1,) )
GL_HI_BIAS_NV = constant.Constant( 'GL_HI_BIAS_NV', 0x8714 )
glget.addGLGetConstant( GL_HI_BIAS_NV, (1,) )
GL_LO_BIAS_NV = constant.Constant( 'GL_LO_BIAS_NV', 0x8715 )
glget.addGLGetConstant( GL_LO_BIAS_NV, (1,) )
GL_DS_BIAS_NV = constant.Constant( 'GL_DS_BIAS_NV', 0x8716 )
glget.addGLGetConstant( GL_DS_BIAS_NV, (1,) )
GL_DT_BIAS_NV = constant.Constant( 'GL_DT_BIAS_NV', 0x8717 )
glget.addGLGetConstant( GL_DT_BIAS_NV, (1,) )
GL_MAGNITUDE_BIAS_NV = constant.Constant( 'GL_MAGNITUDE_BIAS_NV', 0x8718 )
glget.addGLGetConstant( GL_MAGNITUDE_BIAS_NV, (1,) )
GL_VIBRANCE_BIAS_NV = constant.Constant( 'GL_VIBRANCE_BIAS_NV', 0x8719 )
glget.addGLGetConstant( GL_VIBRANCE_BIAS_NV, (1,) )
GL_TEXTURE_BORDER_VALUES_NV = constant.Constant( 'GL_TEXTURE_BORDER_VALUES_NV', 0x871A )
GL_TEXTURE_HI_SIZE_NV = constant.Constant( 'GL_TEXTURE_HI_SIZE_NV', 0x871B )
GL_TEXTURE_LO_SIZE_NV = constant.Constant( 'GL_TEXTURE_LO_SIZE_NV', 0x871C )
GL_TEXTURE_DS_SIZE_NV = constant.Constant( 'GL_TEXTURE_DS_SIZE_NV', 0x871D )
GL_TEXTURE_DT_SIZE_NV = constant.Constant( 'GL_TEXTURE_DT_SIZE_NV', 0x871E )
GL_TEXTURE_MAG_SIZE_NV = constant.Constant( 'GL_TEXTURE_MAG_SIZE_NV', 0x871F )


def glInitTextureShaderNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.histogram

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_histogram'
_DEPRECATED = False
GL_HISTOGRAM_EXT = constant.Constant( 'GL_HISTOGRAM_EXT', 0x8024 )
glget.addGLGetConstant( GL_HISTOGRAM_EXT, (1,) )
GL_PROXY_HISTOGRAM_EXT = constant.Constant( 'GL_PROXY_HISTOGRAM_EXT', 0x8025 )
GL_HISTOGRAM_WIDTH_EXT = constant.Constant( 'GL_HISTOGRAM_WIDTH_EXT', 0x8026 )
GL_HISTOGRAM_FORMAT_EXT = constant.Constant( 'GL_HISTOGRAM_FORMAT_EXT', 0x8027 )
GL_HISTOGRAM_RED_SIZE_EXT = constant.Constant( 'GL_HISTOGRAM_RED_SIZE_EXT', 0x8028 )
GL_HISTOGRAM_GREEN_SIZE_EXT = constant.Constant( 'GL_HISTOGRAM_GREEN_SIZE_EXT', 0x8029 )
GL_HISTOGRAM_BLUE_SIZE_EXT = constant.Constant( 'GL_HISTOGRAM_BLUE_SIZE_EXT', 0x802A )
GL_HISTOGRAM_ALPHA_SIZE_EXT = constant.Constant( 'GL_HISTOGRAM_ALPHA_SIZE_EXT', 0x802B )
GL_HISTOGRAM_LUMINANCE_SIZE_EXT = constant.Constant( 'GL_HISTOGRAM_LUMINANCE_SIZE_EXT', 0x802C )
GL_HISTOGRAM_SINK_EXT = constant.Constant( 'GL_HISTOGRAM_SINK_EXT', 0x802D )
GL_MINMAX_EXT = constant.Constant( 'GL_MINMAX_EXT', 0x802E )
glget.addGLGetConstant( GL_MINMAX_EXT, (1,) )
GL_MINMAX_FORMAT_EXT = constant.Constant( 'GL_MINMAX_FORMAT_EXT', 0x802F )
GL_MINMAX_SINK_EXT = constant.Constant( 'GL_MINMAX_SINK_EXT', 0x8030 )
GL_TABLE_TOO_LARGE_EXT = constant.Constant( 'GL_TABLE_TOO_LARGE_EXT', 0x8031 )
glGetHistogramEXT = platform.createExtensionFunction( 
'glGetHistogramEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLboolean,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glGetHistogramEXT(GLenum(target), GLboolean(reset), GLenum(format), GLenum(type), c_void_p(values)) -> None',
argNames=('target','reset','format','type','values',),
deprecated=_DEPRECATED,
)

glGetHistogramParameterfvEXT = platform.createExtensionFunction( 
'glGetHistogramParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetHistogramParameterfvEXT(GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetHistogramParameterivEXT = platform.createExtensionFunction( 
'glGetHistogramParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetHistogramParameterivEXT(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMinmaxEXT = platform.createExtensionFunction( 
'glGetMinmaxEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLboolean,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glGetMinmaxEXT(GLenum(target), GLboolean(reset), GLenum(format), GLenum(type), c_void_p(values)) -> None',
argNames=('target','reset','format','type','values',),
deprecated=_DEPRECATED,
)

glGetMinmaxParameterfvEXT = platform.createExtensionFunction( 
'glGetMinmaxParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMinmaxParameterfvEXT(GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMinmaxParameterivEXT = platform.createExtensionFunction( 
'glGetMinmaxParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetMinmaxParameterivEXT(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glHistogramEXT = platform.createExtensionFunction( 
'glHistogramEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLenum,constants.GLboolean,),
doc='glHistogramEXT(GLenum(target), GLsizei(width), GLenum(internalformat), GLboolean(sink)) -> None',
argNames=('target','width','internalformat','sink',),
deprecated=_DEPRECATED,
)

glMinmaxEXT = platform.createExtensionFunction( 
'glMinmaxEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLboolean,),
doc='glMinmaxEXT(GLenum(target), GLenum(internalformat), GLboolean(sink)) -> None',
argNames=('target','internalformat','sink',),
deprecated=_DEPRECATED,
)

glResetHistogramEXT = platform.createExtensionFunction( 
'glResetHistogramEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glResetHistogramEXT(GLenum(target)) -> None',
argNames=('target',),
deprecated=_DEPRECATED,
)

glResetMinmaxEXT = platform.createExtensionFunction( 
'glResetMinmaxEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glResetMinmaxEXT(GLenum(target)) -> None',
argNames=('target',),
deprecated=_DEPRECATED,
)


def glInitHistogramEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.blend_color

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_blend_color'
_DEPRECATED = False
GL_CONSTANT_COLOR_EXT = constant.Constant( 'GL_CONSTANT_COLOR_EXT', 0x8001 )
GL_ONE_MINUS_CONSTANT_COLOR_EXT = constant.Constant( 'GL_ONE_MINUS_CONSTANT_COLOR_EXT', 0x8002 )
GL_CONSTANT_ALPHA_EXT = constant.Constant( 'GL_CONSTANT_ALPHA_EXT', 0x8003 )
GL_ONE_MINUS_CONSTANT_ALPHA_EXT = constant.Constant( 'GL_ONE_MINUS_CONSTANT_ALPHA_EXT', 0x8004 )
GL_BLEND_COLOR_EXT = constant.Constant( 'GL_BLEND_COLOR_EXT', 0x8005 )
glget.addGLGetConstant( GL_BLEND_COLOR_EXT, (4,) )
glBlendColorEXT = platform.createExtensionFunction( 
'glBlendColorEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLclampf,constants.GLclampf,constants.GLclampf,constants.GLclampf,),
doc='glBlendColorEXT(GLclampf(red), GLclampf(green), GLclampf(blue), GLclampf(alpha)) -> None',
argNames=('red','green','blue','alpha',),
deprecated=_DEPRECATED,
)


def glInitBlendColorEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.clip_volume_hint

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_clip_volume_hint'
_DEPRECATED = False
GL_CLIP_VOLUME_CLIPPING_HINT_EXT = constant.Constant( 'GL_CLIP_VOLUME_CLIPPING_HINT_EXT', 0x80F0 )
glget.addGLGetConstant( GL_CLIP_VOLUME_CLIPPING_HINT_EXT, (1,) )


def glInitClipVolumeHintEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



# BEGIN GENERATED CONTENT (do not edit below this line)

# This content is generated by gengl.py.
# Wrapper for http://developer.download.nvidia.com/opengl/includes/wglext.h
from OpenGL import platform, constant
from ctypes import *
c_void = None


# H (/home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:9)
# H (/home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:9)
GLAPI = constant.Constant( 'GLAPI', 0 )
WGL_WGLEXT_VERSION = constant.Constant( 'WGL_WGLEXT_VERSION', 6 )
# ARB_buffer_region (http://developer.download.nvidia.com/opengl/includes/wglext.h:62)
WGL_FRONT_COLOR_BUFFER_BIT_ARB = constant.Constant( 'WGL_FRONT_COLOR_BUFFER_BIT_ARB', 1 )
WGL_BACK_COLOR_BUFFER_BIT_ARB = constant.Constant( 'WGL_BACK_COLOR_BUFFER_BIT_ARB', 2 )
WGL_DEPTH_BUFFER_BIT_ARB = constant.Constant( 'WGL_DEPTH_BUFFER_BIT_ARB', 4 )
WGL_STENCIL_BUFFER_BIT_ARB = constant.Constant( 'WGL_STENCIL_BUFFER_BIT_ARB', 8 )
# ARB_multisample (http://developer.download.nvidia.com/opengl/includes/wglext.h:69)
WGL_SAMPLE_BUFFERS_ARB = constant.Constant( 'WGL_SAMPLE_BUFFERS_ARB', 8257 )
WGL_SAMPLES_ARB = constant.Constant( 'WGL_SAMPLES_ARB', 8258 )
# ARB_extensions_string (http://developer.download.nvidia.com/opengl/includes/wglext.h:74)
# ARB_pixel_format (http://developer.download.nvidia.com/opengl/includes/wglext.h:77)
WGL_NUMBER_PIXEL_FORMATS_ARB = constant.Constant( 'WGL_NUMBER_PIXEL_FORMATS_ARB', 8192 )
WGL_DRAW_TO_WINDOW_ARB = constant.Constant( 'WGL_DRAW_TO_WINDOW_ARB', 8193 )
WGL_DRAW_TO_BITMAP_ARB = constant.Constant( 'WGL_DRAW_TO_BITMAP_ARB', 8194 )
WGL_ACCELERATION_ARB = constant.Constant( 'WGL_ACCELERATION_ARB', 8195 )
WGL_NEED_PALETTE_ARB = constant.Constant( 'WGL_NEED_PALETTE_ARB', 8196 )
WGL_NEED_SYSTEM_PALETTE_ARB = constant.Constant( 'WGL_NEED_SYSTEM_PALETTE_ARB', 8197 )
WGL_SWAP_LAYER_BUFFERS_ARB = constant.Constant( 'WGL_SWAP_LAYER_BUFFERS_ARB', 8198 )
WGL_SWAP_METHOD_ARB = constant.Constant( 'WGL_SWAP_METHOD_ARB', 8199 )
WGL_NUMBER_OVERLAYS_ARB = constant.Constant( 'WGL_NUMBER_OVERLAYS_ARB', 8200 )
WGL_NUMBER_UNDERLAYS_ARB = constant.Constant( 'WGL_NUMBER_UNDERLAYS_ARB', 8201 )
WGL_TRANSPARENT_ARB = constant.Constant( 'WGL_TRANSPARENT_ARB', 8202 )
WGL_TRANSPARENT_RED_VALUE_ARB = constant.Constant( 'WGL_TRANSPARENT_RED_VALUE_ARB', 8247 )
WGL_TRANSPARENT_GREEN_VALUE_ARB = constant.Constant( 'WGL_TRANSPARENT_GREEN_VALUE_ARB', 8248 )
WGL_TRANSPARENT_BLUE_VALUE_ARB = constant.Constant( 'WGL_TRANSPARENT_BLUE_VALUE_ARB', 8249 )
WGL_TRANSPARENT_ALPHA_VALUE_ARB = constant.Constant( 'WGL_TRANSPARENT_ALPHA_VALUE_ARB', 8250 )
WGL_TRANSPARENT_INDEX_VALUE_ARB = constant.Constant( 'WGL_TRANSPARENT_INDEX_VALUE_ARB', 8251 )
WGL_SHARE_DEPTH_ARB = constant.Constant( 'WGL_SHARE_DEPTH_ARB', 8204 )
WGL_SHARE_STENCIL_ARB = constant.Constant( 'WGL_SHARE_STENCIL_ARB', 8205 )
WGL_SHARE_ACCUM_ARB = constant.Constant( 'WGL_SHARE_ACCUM_ARB', 8206 )
WGL_SUPPORT_GDI_ARB = constant.Constant( 'WGL_SUPPORT_GDI_ARB', 8207 )
WGL_SUPPORT_OPENGL_ARB = constant.Constant( 'WGL_SUPPORT_OPENGL_ARB', 8208 )
WGL_DOUBLE_BUFFER_ARB = constant.Constant( 'WGL_DOUBLE_BUFFER_ARB', 8209 )
WGL_STEREO_ARB = constant.Constant( 'WGL_STEREO_ARB', 8210 )
WGL_PIXEL_TYPE_ARB = constant.Constant( 'WGL_PIXEL_TYPE_ARB', 8211 )
WGL_COLOR_BITS_ARB = constant.Constant( 'WGL_COLOR_BITS_ARB', 8212 )
WGL_RED_BITS_ARB = constant.Constant( 'WGL_RED_BITS_ARB', 8213 )
WGL_RED_SHIFT_ARB = constant.Constant( 'WGL_RED_SHIFT_ARB', 8214 )
WGL_GREEN_BITS_ARB = constant.Constant( 'WGL_GREEN_BITS_ARB', 8215 )
WGL_GREEN_SHIFT_ARB = constant.Constant( 'WGL_GREEN_SHIFT_ARB', 8216 )
WGL_BLUE_BITS_ARB = constant.Constant( 'WGL_BLUE_BITS_ARB', 8217 )
WGL_BLUE_SHIFT_ARB = constant.Constant( 'WGL_BLUE_SHIFT_ARB', 8218 )
WGL_ALPHA_BITS_ARB = constant.Constant( 'WGL_ALPHA_BITS_ARB', 8219 )
WGL_ALPHA_SHIFT_ARB = constant.Constant( 'WGL_ALPHA_SHIFT_ARB', 8220 )
WGL_ACCUM_BITS_ARB = constant.Constant( 'WGL_ACCUM_BITS_ARB', 8221 )
WGL_ACCUM_RED_BITS_ARB = constant.Constant( 'WGL_ACCUM_RED_BITS_ARB', 8222 )
WGL_ACCUM_GREEN_BITS_ARB = constant.Constant( 'WGL_ACCUM_GREEN_BITS_ARB', 8223 )
WGL_ACCUM_BLUE_BITS_ARB = constant.Constant( 'WGL_ACCUM_BLUE_BITS_ARB', 8224 )
WGL_ACCUM_ALPHA_BITS_ARB = constant.Constant( 'WGL_ACCUM_ALPHA_BITS_ARB', 8225 )
WGL_DEPTH_BITS_ARB = constant.Constant( 'WGL_DEPTH_BITS_ARB', 8226 )
WGL_STENCIL_BITS_ARB = constant.Constant( 'WGL_STENCIL_BITS_ARB', 8227 )
WGL_AUX_BUFFERS_ARB = constant.Constant( 'WGL_AUX_BUFFERS_ARB', 8228 )
WGL_NO_ACCELERATION_ARB = constant.Constant( 'WGL_NO_ACCELERATION_ARB', 8229 )
WGL_GENERIC_ACCELERATION_ARB = constant.Constant( 'WGL_GENERIC_ACCELERATION_ARB', 8230 )
WGL_FULL_ACCELERATION_ARB = constant.Constant( 'WGL_FULL_ACCELERATION_ARB', 8231 )
WGL_SWAP_EXCHANGE_ARB = constant.Constant( 'WGL_SWAP_EXCHANGE_ARB', 8232 )
WGL_SWAP_COPY_ARB = constant.Constant( 'WGL_SWAP_COPY_ARB', 8233 )
WGL_SWAP_UNDEFINED_ARB = constant.Constant( 'WGL_SWAP_UNDEFINED_ARB', 8234 )
WGL_TYPE_RGBA_ARB = constant.Constant( 'WGL_TYPE_RGBA_ARB', 8235 )
WGL_TYPE_COLORINDEX_ARB = constant.Constant( 'WGL_TYPE_COLORINDEX_ARB', 8236 )
# ARB_make_current_read (http://developer.download.nvidia.com/opengl/includes/wglext.h:129)
ERROR_INVALID_PIXEL_TYPE_ARB = constant.Constant( 'ERROR_INVALID_PIXEL_TYPE_ARB', 8259 )
ERROR_INCOMPATIBLE_DEVICE_CONTEXTS_ARB = constant.Constant( 'ERROR_INCOMPATIBLE_DEVICE_CONTEXTS_ARB', 8276 )
# ARB_pbuffer (http://developer.download.nvidia.com/opengl/includes/wglext.h:134)
WGL_DRAW_TO_PBUFFER_ARB = constant.Constant( 'WGL_DRAW_TO_PBUFFER_ARB', 8237 )
WGL_MAX_PBUFFER_PIXELS_ARB = constant.Constant( 'WGL_MAX_PBUFFER_PIXELS_ARB', 8238 )
WGL_MAX_PBUFFER_WIDTH_ARB = constant.Constant( 'WGL_MAX_PBUFFER_WIDTH_ARB', 8239 )
WGL_MAX_PBUFFER_HEIGHT_ARB = constant.Constant( 'WGL_MAX_PBUFFER_HEIGHT_ARB', 8240 )
WGL_PBUFFER_LARGEST_ARB = constant.Constant( 'WGL_PBUFFER_LARGEST_ARB', 8243 )
WGL_PBUFFER_WIDTH_ARB = constant.Constant( 'WGL_PBUFFER_WIDTH_ARB', 8244 )
WGL_PBUFFER_HEIGHT_ARB = constant.Constant( 'WGL_PBUFFER_HEIGHT_ARB', 8245 )
WGL_PBUFFER_LOST_ARB = constant.Constant( 'WGL_PBUFFER_LOST_ARB', 8246 )
# ARB_render_texture (http://developer.download.nvidia.com/opengl/includes/wglext.h:145)
WGL_BIND_TO_TEXTURE_RGB_ARB = constant.Constant( 'WGL_BIND_TO_TEXTURE_RGB_ARB', 8304 )
WGL_BIND_TO_TEXTURE_RGBA_ARB = constant.Constant( 'WGL_BIND_TO_TEXTURE_RGBA_ARB', 8305 )
WGL_TEXTURE_FORMAT_ARB = constant.Constant( 'WGL_TEXTURE_FORMAT_ARB', 8306 )
WGL_TEXTURE_TARGET_ARB = constant.Constant( 'WGL_TEXTURE_TARGET_ARB', 8307 )
WGL_MIPMAP_TEXTURE_ARB = constant.Constant( 'WGL_MIPMAP_TEXTURE_ARB', 8308 )
WGL_TEXTURE_RGB_ARB = constant.Constant( 'WGL_TEXTURE_RGB_ARB', 8309 )
WGL_TEXTURE_RGBA_ARB = constant.Constant( 'WGL_TEXTURE_RGBA_ARB', 8310 )
WGL_NO_TEXTURE_ARB = constant.Constant( 'WGL_NO_TEXTURE_ARB', 8311 )
WGL_TEXTURE_CUBE_MAP_ARB = constant.Constant( 'WGL_TEXTURE_CUBE_MAP_ARB', 8312 )
WGL_TEXTURE_1D_ARB = constant.Constant( 'WGL_TEXTURE_1D_ARB', 8313 )
WGL_TEXTURE_2D_ARB = constant.Constant( 'WGL_TEXTURE_2D_ARB', 8314 )
WGL_MIPMAP_LEVEL_ARB = constant.Constant( 'WGL_MIPMAP_LEVEL_ARB', 8315 )
WGL_CUBE_MAP_FACE_ARB = constant.Constant( 'WGL_CUBE_MAP_FACE_ARB', 8316 )
WGL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB = constant.Constant( 'WGL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB', 8317 )
WGL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB = constant.Constant( 'WGL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB', 8318 )
WGL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB = constant.Constant( 'WGL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB', 8319 )
WGL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB = constant.Constant( 'WGL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB', 8320 )
WGL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB = constant.Constant( 'WGL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB', 8321 )
WGL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB = constant.Constant( 'WGL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB', 8322 )
WGL_FRONT_LEFT_ARB = constant.Constant( 'WGL_FRONT_LEFT_ARB', 8323 )
WGL_FRONT_RIGHT_ARB = constant.Constant( 'WGL_FRONT_RIGHT_ARB', 8324 )
WGL_BACK_LEFT_ARB = constant.Constant( 'WGL_BACK_LEFT_ARB', 8325 )
WGL_BACK_RIGHT_ARB = constant.Constant( 'WGL_BACK_RIGHT_ARB', 8326 )
WGL_AUX0_ARB = constant.Constant( 'WGL_AUX0_ARB', 8327 )
WGL_AUX1_ARB = constant.Constant( 'WGL_AUX1_ARB', 8328 )
WGL_AUX2_ARB = constant.Constant( 'WGL_AUX2_ARB', 8329 )
WGL_AUX3_ARB = constant.Constant( 'WGL_AUX3_ARB', 8330 )
WGL_AUX4_ARB = constant.Constant( 'WGL_AUX4_ARB', 8331 )
WGL_AUX5_ARB = constant.Constant( 'WGL_AUX5_ARB', 8332 )
WGL_AUX6_ARB = constant.Constant( 'WGL_AUX6_ARB', 8333 )
WGL_AUX7_ARB = constant.Constant( 'WGL_AUX7_ARB', 8334 )
WGL_AUX8_ARB = constant.Constant( 'WGL_AUX8_ARB', 8335 )
WGL_AUX9_ARB = constant.Constant( 'WGL_AUX9_ARB', 8336 )
# ARB_pixel_format_float (http://developer.download.nvidia.com/opengl/includes/wglext.h:181)
WGL_TYPE_RGBA_FLOAT_ARB = constant.Constant( 'WGL_TYPE_RGBA_FLOAT_ARB', 8608 )
# EXT_make_current_read (http://developer.download.nvidia.com/opengl/includes/wglext.h:185)
ERROR_INVALID_PIXEL_TYPE_EXT = constant.Constant( 'ERROR_INVALID_PIXEL_TYPE_EXT', 8259 )
# EXT_pixel_format (http://developer.download.nvidia.com/opengl/includes/wglext.h:189)
WGL_NUMBER_PIXEL_FORMATS_EXT = constant.Constant( 'WGL_NUMBER_PIXEL_FORMATS_EXT', 8192 )
WGL_DRAW_TO_WINDOW_EXT = constant.Constant( 'WGL_DRAW_TO_WINDOW_EXT', 8193 )
WGL_DRAW_TO_BITMAP_EXT = constant.Constant( 'WGL_DRAW_TO_BITMAP_EXT', 8194 )
WGL_ACCELERATION_EXT = constant.Constant( 'WGL_ACCELERATION_EXT', 8195 )
WGL_NEED_PALETTE_EXT = constant.Constant( 'WGL_NEED_PALETTE_EXT', 8196 )
WGL_NEED_SYSTEM_PALETTE_EXT = constant.Constant( 'WGL_NEED_SYSTEM_PALETTE_EXT', 8197 )
WGL_SWAP_LAYER_BUFFERS_EXT = constant.Constant( 'WGL_SWAP_LAYER_BUFFERS_EXT', 8198 )
WGL_SWAP_METHOD_EXT = constant.Constant( 'WGL_SWAP_METHOD_EXT', 8199 )
WGL_NUMBER_OVERLAYS_EXT = constant.Constant( 'WGL_NUMBER_OVERLAYS_EXT', 8200 )
WGL_NUMBER_UNDERLAYS_EXT = constant.Constant( 'WGL_NUMBER_UNDERLAYS_EXT', 8201 )
WGL_TRANSPARENT_EXT = constant.Constant( 'WGL_TRANSPARENT_EXT', 8202 )
WGL_TRANSPARENT_VALUE_EXT = constant.Constant( 'WGL_TRANSPARENT_VALUE_EXT', 8203 )
WGL_SHARE_DEPTH_EXT = constant.Constant( 'WGL_SHARE_DEPTH_EXT', 8204 )
WGL_SHARE_STENCIL_EXT = constant.Constant( 'WGL_SHARE_STENCIL_EXT', 8205 )
WGL_SHARE_ACCUM_EXT = constant.Constant( 'WGL_SHARE_ACCUM_EXT', 8206 )
WGL_SUPPORT_GDI_EXT = constant.Constant( 'WGL_SUPPORT_GDI_EXT', 8207 )
WGL_SUPPORT_OPENGL_EXT = constant.Constant( 'WGL_SUPPORT_OPENGL_EXT', 8208 )
WGL_DOUBLE_BUFFER_EXT = constant.Constant( 'WGL_DOUBLE_BUFFER_EXT', 8209 )
WGL_STEREO_EXT = constant.Constant( 'WGL_STEREO_EXT', 8210 )
WGL_PIXEL_TYPE_EXT = constant.Constant( 'WGL_PIXEL_TYPE_EXT', 8211 )
WGL_COLOR_BITS_EXT = constant.Constant( 'WGL_COLOR_BITS_EXT', 8212 )
WGL_RED_BITS_EXT = constant.Constant( 'WGL_RED_BITS_EXT', 8213 )
WGL_RED_SHIFT_EXT = constant.Constant( 'WGL_RED_SHIFT_EXT', 8214 )
WGL_GREEN_BITS_EXT = constant.Constant( 'WGL_GREEN_BITS_EXT', 8215 )
WGL_GREEN_SHIFT_EXT = constant.Constant( 'WGL_GREEN_SHIFT_EXT', 8216 )
WGL_BLUE_BITS_EXT = constant.Constant( 'WGL_BLUE_BITS_EXT', 8217 )
WGL_BLUE_SHIFT_EXT = constant.Constant( 'WGL_BLUE_SHIFT_EXT', 8218 )
WGL_ALPHA_BITS_EXT = constant.Constant( 'WGL_ALPHA_BITS_EXT', 8219 )
WGL_ALPHA_SHIFT_EXT = constant.Constant( 'WGL_ALPHA_SHIFT_EXT', 8220 )
WGL_ACCUM_BITS_EXT = constant.Constant( 'WGL_ACCUM_BITS_EXT', 8221 )
WGL_ACCUM_RED_BITS_EXT = constant.Constant( 'WGL_ACCUM_RED_BITS_EXT', 8222 )
WGL_ACCUM_GREEN_BITS_EXT = constant.Constant( 'WGL_ACCUM_GREEN_BITS_EXT', 8223 )
WGL_ACCUM_BLUE_BITS_EXT = constant.Constant( 'WGL_ACCUM_BLUE_BITS_EXT', 8224 )
WGL_ACCUM_ALPHA_BITS_EXT = constant.Constant( 'WGL_ACCUM_ALPHA_BITS_EXT', 8225 )
WGL_DEPTH_BITS_EXT = constant.Constant( 'WGL_DEPTH_BITS_EXT', 8226 )
WGL_STENCIL_BITS_EXT = constant.Constant( 'WGL_STENCIL_BITS_EXT', 8227 )
WGL_AUX_BUFFERS_EXT = constant.Constant( 'WGL_AUX_BUFFERS_EXT', 8228 )
WGL_NO_ACCELERATION_EXT = constant.Constant( 'WGL_NO_ACCELERATION_EXT', 8229 )
WGL_GENERIC_ACCELERATION_EXT = constant.Constant( 'WGL_GENERIC_ACCELERATION_EXT', 8230 )
WGL_FULL_ACCELERATION_EXT = constant.Constant( 'WGL_FULL_ACCELERATION_EXT', 8231 )
WGL_SWAP_EXCHANGE_EXT = constant.Constant( 'WGL_SWAP_EXCHANGE_EXT', 8232 )
WGL_SWAP_COPY_EXT = constant.Constant( 'WGL_SWAP_COPY_EXT', 8233 )
WGL_SWAP_UNDEFINED_EXT = constant.Constant( 'WGL_SWAP_UNDEFINED_EXT', 8234 )
WGL_TYPE_RGBA_EXT = constant.Constant( 'WGL_TYPE_RGBA_EXT', 8235 )
WGL_TYPE_COLORINDEX_EXT = constant.Constant( 'WGL_TYPE_COLORINDEX_EXT', 8236 )
# EXT_pbuffer (http://developer.download.nvidia.com/opengl/includes/wglext.h:237)
WGL_DRAW_TO_PBUFFER_EXT = constant.Constant( 'WGL_DRAW_TO_PBUFFER_EXT', 8237 )
WGL_MAX_PBUFFER_PIXELS_EXT = constant.Constant( 'WGL_MAX_PBUFFER_PIXELS_EXT', 8238 )
WGL_MAX_PBUFFER_WIDTH_EXT = constant.Constant( 'WGL_MAX_PBUFFER_WIDTH_EXT', 8239 )
WGL_MAX_PBUFFER_HEIGHT_EXT = constant.Constant( 'WGL_MAX_PBUFFER_HEIGHT_EXT', 8240 )
WGL_OPTIMAL_PBUFFER_WIDTH_EXT = constant.Constant( 'WGL_OPTIMAL_PBUFFER_WIDTH_EXT', 8241 )
WGL_OPTIMAL_PBUFFER_HEIGHT_EXT = constant.Constant( 'WGL_OPTIMAL_PBUFFER_HEIGHT_EXT', 8242 )
WGL_PBUFFER_LARGEST_EXT = constant.Constant( 'WGL_PBUFFER_LARGEST_EXT', 8243 )
WGL_PBUFFER_WIDTH_EXT = constant.Constant( 'WGL_PBUFFER_WIDTH_EXT', 8244 )
WGL_PBUFFER_HEIGHT_EXT = constant.Constant( 'WGL_PBUFFER_HEIGHT_EXT', 8245 )
# EXT_depth_float (http://developer.download.nvidia.com/opengl/includes/wglext.h:249)
WGL_DEPTH_FLOAT_EXT = constant.Constant( 'WGL_DEPTH_FLOAT_EXT', 8256 )
# 3DFX_multisample (http://developer.download.nvidia.com/opengl/includes/wglext.h:253)
WGL_SAMPLE_BUFFERS_3DFX = constant.Constant( 'WGL_SAMPLE_BUFFERS_3DFX', 8288 )
WGL_SAMPLES_3DFX = constant.Constant( 'WGL_SAMPLES_3DFX', 8289 )
# EXT_multisample (http://developer.download.nvidia.com/opengl/includes/wglext.h:258)
WGL_SAMPLE_BUFFERS_EXT = constant.Constant( 'WGL_SAMPLE_BUFFERS_EXT', 8257 )
WGL_SAMPLES_EXT = constant.Constant( 'WGL_SAMPLES_EXT', 8258 )
# I3D_digital_video_control (http://developer.download.nvidia.com/opengl/includes/wglext.h:263)
WGL_DIGITAL_VIDEO_CURSOR_ALPHA_FRAMEBUFFER_I3D = constant.Constant( 'WGL_DIGITAL_VIDEO_CURSOR_ALPHA_FRAMEBUFFER_I3D', 8272 )
WGL_DIGITAL_VIDEO_CURSOR_ALPHA_VALUE_I3D = constant.Constant( 'WGL_DIGITAL_VIDEO_CURSOR_ALPHA_VALUE_I3D', 8273 )
WGL_DIGITAL_VIDEO_CURSOR_INCLUDED_I3D = constant.Constant( 'WGL_DIGITAL_VIDEO_CURSOR_INCLUDED_I3D', 8274 )
WGL_DIGITAL_VIDEO_GAMMA_CORRECTED_I3D = constant.Constant( 'WGL_DIGITAL_VIDEO_GAMMA_CORRECTED_I3D', 8275 )
# I3D_gamma (http://developer.download.nvidia.com/opengl/includes/wglext.h:270)
WGL_GAMMA_TABLE_SIZE_I3D = constant.Constant( 'WGL_GAMMA_TABLE_SIZE_I3D', 8270 )
WGL_GAMMA_EXCLUDE_DESKTOP_I3D = constant.Constant( 'WGL_GAMMA_EXCLUDE_DESKTOP_I3D', 8271 )
# I3D_genlock (http://developer.download.nvidia.com/opengl/includes/wglext.h:275)
WGL_GENLOCK_SOURCE_MULTIVIEW_I3D = constant.Constant( 'WGL_GENLOCK_SOURCE_MULTIVIEW_I3D', 8260 )
WGL_GENLOCK_SOURCE_EXTENAL_SYNC_I3D = constant.Constant( 'WGL_GENLOCK_SOURCE_EXTENAL_SYNC_I3D', 8261 )
WGL_GENLOCK_SOURCE_EXTENAL_FIELD_I3D = constant.Constant( 'WGL_GENLOCK_SOURCE_EXTENAL_FIELD_I3D', 8262 )
WGL_GENLOCK_SOURCE_EXTENAL_TTL_I3D = constant.Constant( 'WGL_GENLOCK_SOURCE_EXTENAL_TTL_I3D', 8263 )
WGL_GENLOCK_SOURCE_DIGITAL_SYNC_I3D = constant.Constant( 'WGL_GENLOCK_SOURCE_DIGITAL_SYNC_I3D', 8264 )
WGL_GENLOCK_SOURCE_DIGITAL_FIELD_I3D = constant.Constant( 'WGL_GENLOCK_SOURCE_DIGITAL_FIELD_I3D', 8265 )
WGL_GENLOCK_SOURCE_EDGE_FALLING_I3D = constant.Constant( 'WGL_GENLOCK_SOURCE_EDGE_FALLING_I3D', 8266 )
WGL_GENLOCK_SOURCE_EDGE_RISING_I3D = constant.Constant( 'WGL_GENLOCK_SOURCE_EDGE_RISING_I3D', 8267 )
WGL_GENLOCK_SOURCE_EDGE_BOTH_I3D = constant.Constant( 'WGL_GENLOCK_SOURCE_EDGE_BOTH_I3D', 8268 )
# I3D_image_buffer (http://developer.download.nvidia.com/opengl/includes/wglext.h:287)
WGL_IMAGE_BUFFER_MIN_ACCESS_I3D = constant.Constant( 'WGL_IMAGE_BUFFER_MIN_ACCESS_I3D', 1 )
WGL_IMAGE_BUFFER_LOCK_I3D = constant.Constant( 'WGL_IMAGE_BUFFER_LOCK_I3D', 2 )
# I3D_swap_frame_lock (http://developer.download.nvidia.com/opengl/includes/wglext.h:292)
# NV_render_depth_texture (http://developer.download.nvidia.com/opengl/includes/wglext.h:295)
WGL_BIND_TO_TEXTURE_DEPTH_NV = constant.Constant( 'WGL_BIND_TO_TEXTURE_DEPTH_NV', 8355 )
WGL_BIND_TO_TEXTURE_RECTANGLE_DEPTH_NV = constant.Constant( 'WGL_BIND_TO_TEXTURE_RECTANGLE_DEPTH_NV', 8356 )
WGL_DEPTH_TEXTURE_FORMAT_NV = constant.Constant( 'WGL_DEPTH_TEXTURE_FORMAT_NV', 8357 )
WGL_TEXTURE_DEPTH_COMPONENT_NV = constant.Constant( 'WGL_TEXTURE_DEPTH_COMPONENT_NV', 8358 )
WGL_DEPTH_COMPONENT_NV = constant.Constant( 'WGL_DEPTH_COMPONENT_NV', 8359 )
# NV_render_texture_rectangle (http://developer.download.nvidia.com/opengl/includes/wglext.h:303)
WGL_BIND_TO_TEXTURE_RECTANGLE_RGB_NV = constant.Constant( 'WGL_BIND_TO_TEXTURE_RECTANGLE_RGB_NV', 8352 )
WGL_BIND_TO_TEXTURE_RECTANGLE_RGBA_NV = constant.Constant( 'WGL_BIND_TO_TEXTURE_RECTANGLE_RGBA_NV', 8353 )
WGL_TEXTURE_RECTANGLE_NV = constant.Constant( 'WGL_TEXTURE_RECTANGLE_NV', 8354 )
# ATI_pixel_format_float (http://developer.download.nvidia.com/opengl/includes/wglext.h:309)
WGL_TYPE_RGBA_FLOAT_ATI = constant.Constant( 'WGL_TYPE_RGBA_FLOAT_ATI', 8608 )
WGL_RGBA_FLOAT_MODE_ATI = constant.Constant( 'WGL_RGBA_FLOAT_MODE_ATI', 34848 )
WGL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI = constant.Constant( 'WGL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI', 34869 )
# NV_float_buffer (http://developer.download.nvidia.com/opengl/includes/wglext.h:315)
WGL_FLOAT_COMPONENTS_NV = constant.Constant( 'WGL_FLOAT_COMPONENTS_NV', 8368 )
WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_R_NV = constant.Constant( 'WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_R_NV', 8369 )
WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RG_NV = constant.Constant( 'WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RG_NV', 8370 )
WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGB_NV = constant.Constant( 'WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGB_NV', 8371 )
WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGBA_NV = constant.Constant( 'WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGBA_NV', 8372 )
WGL_TEXTURE_FLOAT_R_NV = constant.Constant( 'WGL_TEXTURE_FLOAT_R_NV', 8373 )
WGL_TEXTURE_FLOAT_RG_NV = constant.Constant( 'WGL_TEXTURE_FLOAT_RG_NV', 8374 )
WGL_TEXTURE_FLOAT_RGB_NV = constant.Constant( 'WGL_TEXTURE_FLOAT_RGB_NV', 8375 )
WGL_TEXTURE_FLOAT_RGBA_NV = constant.Constant( 'WGL_TEXTURE_FLOAT_RGBA_NV', 8376 )
# NV_swap_group (http://developer.download.nvidia.com/opengl/includes/wglext.h:327)
# NV_gpu_affinity (http://developer.download.nvidia.com/opengl/includes/wglext.h:330)
WGL_ERROR_INCOMPATIBLE_AFFINITY_MASKS_NV = constant.Constant( 'WGL_ERROR_INCOMPATIBLE_AFFINITY_MASKS_NV', 8400 )
WGL_ERROR_MISSING_AFFINITY_MASK_NV = constant.Constant( 'WGL_ERROR_MISSING_AFFINITY_MASK_NV', 8401 )
# ARB_pbuffer (http://developer.download.nvidia.com/opengl/includes/wglext.h:338)
HANDLE = POINTER(None) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:60
HPBUFFERARB = HANDLE 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:339
# EXT_pbuffer (http://developer.download.nvidia.com/opengl/includes/wglext.h:341)
HPBUFFEREXT = HANDLE 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:342
# NV_gpu_affinity (http://developer.download.nvidia.com/opengl/includes/wglext.h:345)
HGPUNV = HANDLE 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:346
class struct__GPU_DEVICE(Structure):
    __slots__ = [
        'cb',
        'DeviceName',
        'DeviceString',
        'Flags',
        'rcVirtualScreen',
    ]
DWORD = c_ulong 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:56
CHAR = c_char 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:49
class struct_tagRECT(Structure):
    __slots__ = [
        'left',
        'top',
        'right',
        'bottom',
    ]
LONG = c_long 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:55
struct_tagRECT._fields_ = [
    ('left', LONG),
    ('top', LONG),
    ('right', LONG),
    ('bottom', LONG),
]

RECT = struct_tagRECT 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:202
struct__GPU_DEVICE._fields_ = [
    ('cb', DWORD),
    ('DeviceName', CHAR * 32),
    ('DeviceString', CHAR * 128),
    ('Flags', DWORD),
    ('rcVirtualScreen', RECT),
]

GPU_DEVICE = struct__GPU_DEVICE 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:353
PGPU_DEVICE = POINTER(struct__GPU_DEVICE) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:353
# ARB_buffer_region (http://developer.download.nvidia.com/opengl/includes/wglext.h:356)
WGL_ARB_buffer_region = constant.Constant( 'WGL_ARB_buffer_region', 1 )
HDC = HANDLE 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:63
UINT = c_uint 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:52
wglCreateBufferRegionARB = platform.createBaseFunction(
    'wglCreateBufferRegionARB', dll=platform.GL, resultType=HANDLE, 
    argTypes=[HDC, c_int, UINT],
    doc='wglCreateBufferRegionARB( HDC(None), c_int(None), UINT(None) ) -> HANDLE', 
    argNames=['None', 'None', 'None'],
)

VOID = None 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:47
wglDeleteBufferRegionARB = platform.createBaseFunction(
    'wglDeleteBufferRegionARB', dll=platform.GL, resultType=VOID, 
    argTypes=[HANDLE],
    doc='wglDeleteBufferRegionARB( HANDLE(None) ) -> VOID', 
    argNames=['None'],
)

BOOL = c_long 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:54
wglSaveBufferRegionARB = platform.createBaseFunction(
    'wglSaveBufferRegionARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HANDLE, c_int, c_int, c_int, c_int],
    doc='wglSaveBufferRegionARB( HANDLE(None), c_int(None), c_int(None), c_int(None), c_int(None) ) -> BOOL', 
    argNames=['None', 'None', 'None', 'None', 'None'],
)

wglRestoreBufferRegionARB = platform.createBaseFunction(
    'wglRestoreBufferRegionARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HANDLE, c_int, c_int, c_int, c_int, c_int, c_int],
    doc='wglRestoreBufferRegionARB( HANDLE(None), c_int(None), c_int(None), c_int(None), c_int(None), c_int(None), c_int(None) ) -> BOOL', 
    argNames=['None', 'None', 'None', 'None', 'None', 'None', 'None'],
)

PFNWGLCREATEBUFFERREGIONARBPROC = CFUNCTYPE(HANDLE, HDC, c_int, UINT) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:364
PFNWGLDELETEBUFFERREGIONARBPROC = CFUNCTYPE(VOID, HANDLE) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:365
PFNWGLSAVEBUFFERREGIONARBPROC = CFUNCTYPE(BOOL, HANDLE, c_int, c_int, c_int, c_int) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:366
PFNWGLRESTOREBUFFERREGIONARBPROC = CFUNCTYPE(BOOL, HANDLE, c_int, c_int, c_int, c_int, c_int, c_int) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:367
# ARB_multisample (http://developer.download.nvidia.com/opengl/includes/wglext.h:370)
WGL_ARB_multisample = constant.Constant( 'WGL_ARB_multisample', 1 )
# ARB_extensions_string (http://developer.download.nvidia.com/opengl/includes/wglext.h:374)
WGL_ARB_extensions_string = constant.Constant( 'WGL_ARB_extensions_string', 1 )
wglGetExtensionsStringARB = platform.createBaseFunction(
    'wglGetExtensionsStringARB', dll=platform.GL, resultType=c_char_p, 
    argTypes=[HDC],
    doc='wglGetExtensionsStringARB( HDC(None) ) -> c_char_p', 
    argNames=['None'],
)

PFNWGLGETEXTENSIONSSTRINGARBPROC = CFUNCTYPE(c_char_p, HDC) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:379
# ARB_pixel_format (http://developer.download.nvidia.com/opengl/includes/wglext.h:382)
WGL_ARB_pixel_format = constant.Constant( 'WGL_ARB_pixel_format', 1 )
wglGetPixelFormatAttribivARB = platform.createBaseFunction(
    'wglGetPixelFormatAttribivARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, c_int, c_int, UINT, POINTER(c_int), POINTER(c_int)],
    doc='wglGetPixelFormatAttribivARB( HDC(None), c_int(None), c_int(None), UINT(None), POINTER(c_int)(), POINTER(c_int)() ) -> BOOL', 
    argNames=['None', 'None', 'None', 'None', '', ''],
)

FLOAT = c_float 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:57
wglGetPixelFormatAttribfvARB = platform.createBaseFunction(
    'wglGetPixelFormatAttribfvARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, c_int, c_int, UINT, POINTER(c_int), POINTER(FLOAT)],
    doc='wglGetPixelFormatAttribfvARB( HDC(None), c_int(None), c_int(None), UINT(None), POINTER(c_int)(), POINTER(FLOAT)() ) -> BOOL', 
    argNames=['None', 'None', 'None', 'None', '', ''],
)

wglChoosePixelFormatARB = platform.createBaseFunction(
    'wglChoosePixelFormatARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(c_int), POINTER(FLOAT), UINT, POINTER(c_int), POINTER(UINT)],
    doc='wglChoosePixelFormatARB( HDC(None), POINTER(c_int)(), POINTER(FLOAT)(), UINT(None), POINTER(c_int)(), POINTER(UINT)() ) -> BOOL', 
    argNames=['None', '', '', 'None', '', ''],
)

PFNWGLGETPIXELFORMATATTRIBIVARBPROC = CFUNCTYPE(BOOL, HDC, c_int, c_int, UINT, POINTER(c_int), POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:389
PFNWGLGETPIXELFORMATATTRIBFVARBPROC = CFUNCTYPE(BOOL, HDC, c_int, c_int, UINT, POINTER(c_int), POINTER(FLOAT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:390
PFNWGLCHOOSEPIXELFORMATARBPROC = CFUNCTYPE(BOOL, HDC, POINTER(c_int), POINTER(FLOAT), UINT, POINTER(c_int), POINTER(UINT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:391
# ARB_make_current_read (http://developer.download.nvidia.com/opengl/includes/wglext.h:394)
WGL_ARB_make_current_read = constant.Constant( 'WGL_ARB_make_current_read', 1 )
HGLRC = HANDLE 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:62
wglMakeContextCurrentARB = platform.createBaseFunction(
    'wglMakeContextCurrentARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, HDC, HGLRC],
    doc='wglMakeContextCurrentARB( HDC(None), HDC(None), HGLRC(None) ) -> BOOL', 
    argNames=['None', 'None', 'None'],
)

wglGetCurrentReadDCARB = platform.createBaseFunction(
    'wglGetCurrentReadDCARB', dll=platform.GL, resultType=HDC, 
    argTypes=[],
    doc='wglGetCurrentReadDCARB(  ) -> HDC', 
    argNames=[],
)

PFNWGLMAKECONTEXTCURRENTARBPROC = CFUNCTYPE(BOOL, HDC, HDC, HGLRC) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:400
PFNWGLGETCURRENTREADDCARBPROC = CFUNCTYPE(HDC) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:401
# ARB_pbuffer (http://developer.download.nvidia.com/opengl/includes/wglext.h:404)
WGL_ARB_pbuffer = constant.Constant( 'WGL_ARB_pbuffer', 1 )
wglCreatePbufferARB = platform.createBaseFunction(
    'wglCreatePbufferARB', dll=platform.GL, resultType=HPBUFFERARB, 
    argTypes=[HDC, c_int, c_int, c_int, POINTER(c_int)],
    doc='wglCreatePbufferARB( HDC(None), c_int(None), c_int(None), c_int(None), POINTER(c_int)() ) -> HPBUFFERARB', 
    argNames=['None', 'None', 'None', 'None', ''],
)

wglGetPbufferDCARB = platform.createBaseFunction(
    'wglGetPbufferDCARB', dll=platform.GL, resultType=HDC, 
    argTypes=[HPBUFFERARB],
    doc='wglGetPbufferDCARB( HPBUFFERARB(None) ) -> HDC', 
    argNames=['None'],
)

wglReleasePbufferDCARB = platform.createBaseFunction(
    'wglReleasePbufferDCARB', dll=platform.GL, resultType=c_int, 
    argTypes=[HPBUFFERARB, HDC],
    doc='wglReleasePbufferDCARB( HPBUFFERARB(None), HDC(None) ) -> c_int', 
    argNames=['None', 'None'],
)

wglDestroyPbufferARB = platform.createBaseFunction(
    'wglDestroyPbufferARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HPBUFFERARB],
    doc='wglDestroyPbufferARB( HPBUFFERARB(None) ) -> BOOL', 
    argNames=['None'],
)

wglQueryPbufferARB = platform.createBaseFunction(
    'wglQueryPbufferARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HPBUFFERARB, c_int, POINTER(c_int)],
    doc='wglQueryPbufferARB( HPBUFFERARB(None), c_int(None), POINTER(c_int)() ) -> BOOL', 
    argNames=['None', 'None', ''],
)

PFNWGLCREATEPBUFFERARBPROC = CFUNCTYPE(HPBUFFERARB, HDC, c_int, c_int, c_int, POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:413
PFNWGLGETPBUFFERDCARBPROC = CFUNCTYPE(HDC, HPBUFFERARB) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:414
PFNWGLRELEASEPBUFFERDCARBPROC = CFUNCTYPE(c_int, HPBUFFERARB, HDC) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:415
PFNWGLDESTROYPBUFFERARBPROC = CFUNCTYPE(BOOL, HPBUFFERARB) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:416
PFNWGLQUERYPBUFFERARBPROC = CFUNCTYPE(BOOL, HPBUFFERARB, c_int, POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:417
# ARB_render_texture (http://developer.download.nvidia.com/opengl/includes/wglext.h:420)
WGL_ARB_render_texture = constant.Constant( 'WGL_ARB_render_texture', 1 )
wglBindTexImageARB = platform.createBaseFunction(
    'wglBindTexImageARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HPBUFFERARB, c_int],
    doc='wglBindTexImageARB( HPBUFFERARB(None), c_int(None) ) -> BOOL', 
    argNames=['None', 'None'],
)

wglReleaseTexImageARB = platform.createBaseFunction(
    'wglReleaseTexImageARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HPBUFFERARB, c_int],
    doc='wglReleaseTexImageARB( HPBUFFERARB(None), c_int(None) ) -> BOOL', 
    argNames=['None', 'None'],
)

wglSetPbufferAttribARB = platform.createBaseFunction(
    'wglSetPbufferAttribARB', dll=platform.GL, resultType=BOOL, 
    argTypes=[HPBUFFERARB, POINTER(c_int)],
    doc='wglSetPbufferAttribARB( HPBUFFERARB(None), POINTER(c_int)() ) -> BOOL', 
    argNames=['None', ''],
)

PFNWGLBINDTEXIMAGEARBPROC = CFUNCTYPE(BOOL, HPBUFFERARB, c_int) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:427
PFNWGLRELEASETEXIMAGEARBPROC = CFUNCTYPE(BOOL, HPBUFFERARB, c_int) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:428
PFNWGLSETPBUFFERATTRIBARBPROC = CFUNCTYPE(BOOL, HPBUFFERARB, POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:429
# ARB_pixel_format_float (http://developer.download.nvidia.com/opengl/includes/wglext.h:432)
WGL_ARB_pixel_format_float = constant.Constant( 'WGL_ARB_pixel_format_float', 1 )
# EXT_display_color_table (http://developer.download.nvidia.com/opengl/includes/wglext.h:436)
WGL_EXT_display_color_table = constant.Constant( 'WGL_EXT_display_color_table', 1 )
GLboolean = c_ubyte 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:20
GLushort = c_ushort 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:27
wglCreateDisplayColorTableEXT = platform.createBaseFunction(
    'wglCreateDisplayColorTableEXT', dll=platform.GL, resultType=GLboolean, 
    argTypes=[GLushort],
    doc='wglCreateDisplayColorTableEXT( GLushort(None) ) -> GLboolean', 
    argNames=['None'],
)

GLuint = c_uint 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:28
wglLoadDisplayColorTableEXT = platform.createBaseFunction(
    'wglLoadDisplayColorTableEXT', dll=platform.GL, resultType=GLboolean, 
    argTypes=[POINTER(GLushort), GLuint],
    doc='wglLoadDisplayColorTableEXT( POINTER(GLushort)(), GLuint(None) ) -> GLboolean', 
    argNames=['', 'None'],
)

wglBindDisplayColorTableEXT = platform.createBaseFunction(
    'wglBindDisplayColorTableEXT', dll=platform.GL, resultType=GLboolean, 
    argTypes=[GLushort],
    doc='wglBindDisplayColorTableEXT( GLushort(None) ) -> GLboolean', 
    argNames=['None'],
)

wglDestroyDisplayColorTableEXT = platform.createBaseFunction(
    'wglDestroyDisplayColorTableEXT', dll=platform.GL, resultType=VOID, 
    argTypes=[GLushort],
    doc='wglDestroyDisplayColorTableEXT( GLushort(None) ) -> VOID', 
    argNames=['None'],
)

PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC = CFUNCTYPE(GLboolean, GLushort) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:444
PFNWGLLOADDISPLAYCOLORTABLEEXTPROC = CFUNCTYPE(GLboolean, POINTER(GLushort), GLuint) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:445
PFNWGLBINDDISPLAYCOLORTABLEEXTPROC = CFUNCTYPE(GLboolean, GLushort) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:446
PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC = CFUNCTYPE(VOID, GLushort) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:447
# EXT_extensions_string (http://developer.download.nvidia.com/opengl/includes/wglext.h:450)
WGL_EXT_extensions_string = constant.Constant( 'WGL_EXT_extensions_string', 1 )
wglGetExtensionsStringEXT = platform.createBaseFunction(
    'wglGetExtensionsStringEXT', dll=platform.GL, resultType=c_char_p, 
    argTypes=[],
    doc='wglGetExtensionsStringEXT(  ) -> c_char_p', 
    argNames=[],
)

PFNWGLGETEXTENSIONSSTRINGEXTPROC = CFUNCTYPE(c_char_p) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:455
# EXT_make_current_read (http://developer.download.nvidia.com/opengl/includes/wglext.h:458)
WGL_EXT_make_current_read = constant.Constant( 'WGL_EXT_make_current_read', 1 )
wglMakeContextCurrentEXT = platform.createBaseFunction(
    'wglMakeContextCurrentEXT', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, HDC, HGLRC],
    doc='wglMakeContextCurrentEXT( HDC(None), HDC(None), HGLRC(None) ) -> BOOL', 
    argNames=['None', 'None', 'None'],
)

wglGetCurrentReadDCEXT = platform.createBaseFunction(
    'wglGetCurrentReadDCEXT', dll=platform.GL, resultType=HDC, 
    argTypes=[],
    doc='wglGetCurrentReadDCEXT(  ) -> HDC', 
    argNames=[],
)

PFNWGLMAKECONTEXTCURRENTEXTPROC = CFUNCTYPE(BOOL, HDC, HDC, HGLRC) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:464
PFNWGLGETCURRENTREADDCEXTPROC = CFUNCTYPE(HDC) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:465
# EXT_pbuffer (http://developer.download.nvidia.com/opengl/includes/wglext.h:468)
WGL_EXT_pbuffer = constant.Constant( 'WGL_EXT_pbuffer', 1 )
wglCreatePbufferEXT = platform.createBaseFunction(
    'wglCreatePbufferEXT', dll=platform.GL, resultType=HPBUFFEREXT, 
    argTypes=[HDC, c_int, c_int, c_int, POINTER(c_int)],
    doc='wglCreatePbufferEXT( HDC(None), c_int(None), c_int(None), c_int(None), POINTER(c_int)() ) -> HPBUFFEREXT', 
    argNames=['None', 'None', 'None', 'None', ''],
)

wglGetPbufferDCEXT = platform.createBaseFunction(
    'wglGetPbufferDCEXT', dll=platform.GL, resultType=HDC, 
    argTypes=[HPBUFFEREXT],
    doc='wglGetPbufferDCEXT( HPBUFFEREXT(None) ) -> HDC', 
    argNames=['None'],
)

wglReleasePbufferDCEXT = platform.createBaseFunction(
    'wglReleasePbufferDCEXT', dll=platform.GL, resultType=c_int, 
    argTypes=[HPBUFFEREXT, HDC],
    doc='wglReleasePbufferDCEXT( HPBUFFEREXT(None), HDC(None) ) -> c_int', 
    argNames=['None', 'None'],
)

wglDestroyPbufferEXT = platform.createBaseFunction(
    'wglDestroyPbufferEXT', dll=platform.GL, resultType=BOOL, 
    argTypes=[HPBUFFEREXT],
    doc='wglDestroyPbufferEXT( HPBUFFEREXT(None) ) -> BOOL', 
    argNames=['None'],
)

wglQueryPbufferEXT = platform.createBaseFunction(
    'wglQueryPbufferEXT', dll=platform.GL, resultType=BOOL, 
    argTypes=[HPBUFFEREXT, c_int, POINTER(c_int)],
    doc='wglQueryPbufferEXT( HPBUFFEREXT(None), c_int(None), POINTER(c_int)() ) -> BOOL', 
    argNames=['None', 'None', ''],
)

PFNWGLCREATEPBUFFEREXTPROC = CFUNCTYPE(HPBUFFEREXT, HDC, c_int, c_int, c_int, POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:477
PFNWGLGETPBUFFERDCEXTPROC = CFUNCTYPE(HDC, HPBUFFEREXT) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:478
PFNWGLRELEASEPBUFFERDCEXTPROC = CFUNCTYPE(c_int, HPBUFFEREXT, HDC) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:479
PFNWGLDESTROYPBUFFEREXTPROC = CFUNCTYPE(BOOL, HPBUFFEREXT) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:480
PFNWGLQUERYPBUFFEREXTPROC = CFUNCTYPE(BOOL, HPBUFFEREXT, c_int, POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:481
# EXT_pixel_format (http://developer.download.nvidia.com/opengl/includes/wglext.h:484)
WGL_EXT_pixel_format = constant.Constant( 'WGL_EXT_pixel_format', 1 )
wglGetPixelFormatAttribivEXT = platform.createBaseFunction(
    'wglGetPixelFormatAttribivEXT', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, c_int, c_int, UINT, POINTER(c_int), POINTER(c_int)],
    doc='wglGetPixelFormatAttribivEXT( HDC(None), c_int(None), c_int(None), UINT(None), POINTER(c_int)(), POINTER(c_int)() ) -> BOOL', 
    argNames=['None', 'None', 'None', 'None', '', ''],
)

wglGetPixelFormatAttribfvEXT = platform.createBaseFunction(
    'wglGetPixelFormatAttribfvEXT', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, c_int, c_int, UINT, POINTER(c_int), POINTER(FLOAT)],
    doc='wglGetPixelFormatAttribfvEXT( HDC(None), c_int(None), c_int(None), UINT(None), POINTER(c_int)(), POINTER(FLOAT)() ) -> BOOL', 
    argNames=['None', 'None', 'None', 'None', '', ''],
)

wglChoosePixelFormatEXT = platform.createBaseFunction(
    'wglChoosePixelFormatEXT', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(c_int), POINTER(FLOAT), UINT, POINTER(c_int), POINTER(UINT)],
    doc='wglChoosePixelFormatEXT( HDC(None), POINTER(c_int)(), POINTER(FLOAT)(), UINT(None), POINTER(c_int)(), POINTER(UINT)() ) -> BOOL', 
    argNames=['None', '', '', 'None', '', ''],
)

PFNWGLGETPIXELFORMATATTRIBIVEXTPROC = CFUNCTYPE(BOOL, HDC, c_int, c_int, UINT, POINTER(c_int), POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:491
PFNWGLGETPIXELFORMATATTRIBFVEXTPROC = CFUNCTYPE(BOOL, HDC, c_int, c_int, UINT, POINTER(c_int), POINTER(FLOAT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:492
PFNWGLCHOOSEPIXELFORMATEXTPROC = CFUNCTYPE(BOOL, HDC, POINTER(c_int), POINTER(FLOAT), UINT, POINTER(c_int), POINTER(UINT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:493
# EXT_swap_control (http://developer.download.nvidia.com/opengl/includes/wglext.h:496)
WGL_EXT_swap_control = constant.Constant( 'WGL_EXT_swap_control', 1 )
wglSwapIntervalEXT = platform.createBaseFunction(
    'wglSwapIntervalEXT', dll=platform.GL, resultType=BOOL, 
    argTypes=[c_int],
    doc='wglSwapIntervalEXT( c_int(None) ) -> BOOL', 
    argNames=['None'],
)

wglGetSwapIntervalEXT = platform.createBaseFunction(
    'wglGetSwapIntervalEXT', dll=platform.GL, resultType=c_int, 
    argTypes=[],
    doc='wglGetSwapIntervalEXT(  ) -> c_int', 
    argNames=[],
)

PFNWGLSWAPINTERVALEXTPROC = CFUNCTYPE(BOOL, c_int) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:502
PFNWGLGETSWAPINTERVALEXTPROC = CFUNCTYPE(c_int) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:503
# EXT_depth_float (http://developer.download.nvidia.com/opengl/includes/wglext.h:506)
WGL_EXT_depth_float = constant.Constant( 'WGL_EXT_depth_float', 1 )
# NV_vertex_array_range (http://developer.download.nvidia.com/opengl/includes/wglext.h:510)
WGL_NV_vertex_array_range = constant.Constant( 'WGL_NV_vertex_array_range', 1 )
GLsizei = c_int 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:25
GLfloat = c_float 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:29
wglAllocateMemoryNV = platform.createBaseFunction(
    'wglAllocateMemoryNV', dll=platform.GL, resultType=POINTER(c_void), 
    argTypes=[GLsizei, GLfloat, GLfloat, GLfloat],
    doc='wglAllocateMemoryNV( GLsizei(None), GLfloat(None), GLfloat(None), GLfloat(None) ) -> POINTER(c_void)', 
    argNames=['None', 'None', 'None', 'None'],
)

wglFreeMemoryNV = platform.createBaseFunction(
    'wglFreeMemoryNV', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(None)],
    doc='wglFreeMemoryNV( POINTER(None)() ) -> None', 
    argNames=[''],
)

PFNWGLALLOCATEMEMORYNVPROC = CFUNCTYPE(POINTER(c_void), GLsizei, GLfloat, GLfloat, GLfloat) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:516
PFNWGLFREEMEMORYNVPROC = CFUNCTYPE(None, POINTER(None)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:517
# 3DFX_multisample (http://developer.download.nvidia.com/opengl/includes/wglext.h:520)
WGL_3DFX_multisample = constant.Constant( 'WGL_3DFX_multisample', 1 )
# EXT_multisample (http://developer.download.nvidia.com/opengl/includes/wglext.h:524)
WGL_EXT_multisample = constant.Constant( 'WGL_EXT_multisample', 1 )
# OML_sync_control (http://developer.download.nvidia.com/opengl/includes/wglext.h:528)
WGL_OML_sync_control = constant.Constant( 'WGL_OML_sync_control', 1 )
INT64 = c_longlong 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:44
wglGetSyncValuesOML = platform.createBaseFunction(
    'wglGetSyncValuesOML', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(INT64), POINTER(INT64), POINTER(INT64)],
    doc='wglGetSyncValuesOML( HDC(None), POINTER(INT64)(), POINTER(INT64)(), POINTER(INT64)() ) -> BOOL', 
    argNames=['None', '', '', ''],
)

INT32 = c_int 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:37
wglGetMscRateOML = platform.createBaseFunction(
    'wglGetMscRateOML', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(INT32), POINTER(INT32)],
    doc='wglGetMscRateOML( HDC(None), POINTER(INT32)(), POINTER(INT32)() ) -> BOOL', 
    argNames=['None', '', ''],
)

wglSwapBuffersMscOML = platform.createBaseFunction(
    'wglSwapBuffersMscOML', dll=platform.GL, resultType=INT64, 
    argTypes=[HDC, INT64, INT64, INT64],
    doc='wglSwapBuffersMscOML( HDC(None), INT64(None), INT64(None), INT64(None) ) -> INT64', 
    argNames=['None', 'None', 'None', 'None'],
)

wglSwapLayerBuffersMscOML = platform.createBaseFunction(
    'wglSwapLayerBuffersMscOML', dll=platform.GL, resultType=INT64, 
    argTypes=[HDC, c_int, INT64, INT64, INT64],
    doc='wglSwapLayerBuffersMscOML( HDC(None), c_int(None), INT64(None), INT64(None), INT64(None) ) -> INT64', 
    argNames=['None', 'None', 'None', 'None', 'None'],
)

wglWaitForMscOML = platform.createBaseFunction(
    'wglWaitForMscOML', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, INT64, INT64, INT64, POINTER(INT64), POINTER(INT64), POINTER(INT64)],
    doc='wglWaitForMscOML( HDC(None), INT64(None), INT64(None), INT64(None), POINTER(INT64)(), POINTER(INT64)(), POINTER(INT64)() ) -> BOOL', 
    argNames=['None', 'None', 'None', 'None', '', '', ''],
)

wglWaitForSbcOML = platform.createBaseFunction(
    'wglWaitForSbcOML', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, INT64, POINTER(INT64), POINTER(INT64), POINTER(INT64)],
    doc='wglWaitForSbcOML( HDC(None), INT64(None), POINTER(INT64)(), POINTER(INT64)(), POINTER(INT64)() ) -> BOOL', 
    argNames=['None', 'None', '', '', ''],
)

PFNWGLGETSYNCVALUESOMLPROC = CFUNCTYPE(BOOL, HDC, POINTER(INT64), POINTER(INT64), POINTER(INT64)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:538
PFNWGLGETMSCRATEOMLPROC = CFUNCTYPE(BOOL, HDC, POINTER(INT32), POINTER(INT32)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:539
PFNWGLSWAPBUFFERSMSCOMLPROC = CFUNCTYPE(INT64, HDC, INT64, INT64, INT64) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:540
PFNWGLSWAPLAYERBUFFERSMSCOMLPROC = CFUNCTYPE(INT64, HDC, c_int, INT64, INT64, INT64) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:541
PFNWGLWAITFORMSCOMLPROC = CFUNCTYPE(BOOL, HDC, INT64, INT64, INT64, POINTER(INT64), POINTER(INT64), POINTER(INT64)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:542
PFNWGLWAITFORSBCOMLPROC = CFUNCTYPE(BOOL, HDC, INT64, POINTER(INT64), POINTER(INT64), POINTER(INT64)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:543
# I3D_digital_video_control (http://developer.download.nvidia.com/opengl/includes/wglext.h:546)
WGL_I3D_digital_video_control = constant.Constant( 'WGL_I3D_digital_video_control', 1 )
wglGetDigitalVideoParametersI3D = platform.createBaseFunction(
    'wglGetDigitalVideoParametersI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, c_int, POINTER(c_int)],
    doc='wglGetDigitalVideoParametersI3D( HDC(None), c_int(None), POINTER(c_int)() ) -> BOOL', 
    argNames=['None', 'None', ''],
)

wglSetDigitalVideoParametersI3D = platform.createBaseFunction(
    'wglSetDigitalVideoParametersI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, c_int, POINTER(c_int)],
    doc='wglSetDigitalVideoParametersI3D( HDC(None), c_int(None), POINTER(c_int)() ) -> BOOL', 
    argNames=['None', 'None', ''],
)

PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC = CFUNCTYPE(BOOL, HDC, c_int, POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:552
PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC = CFUNCTYPE(BOOL, HDC, c_int, POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:553
# I3D_gamma (http://developer.download.nvidia.com/opengl/includes/wglext.h:556)
WGL_I3D_gamma = constant.Constant( 'WGL_I3D_gamma', 1 )
wglGetGammaTableParametersI3D = platform.createBaseFunction(
    'wglGetGammaTableParametersI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, c_int, POINTER(c_int)],
    doc='wglGetGammaTableParametersI3D( HDC(None), c_int(None), POINTER(c_int)() ) -> BOOL', 
    argNames=['None', 'None', ''],
)

wglSetGammaTableParametersI3D = platform.createBaseFunction(
    'wglSetGammaTableParametersI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, c_int, POINTER(c_int)],
    doc='wglSetGammaTableParametersI3D( HDC(None), c_int(None), POINTER(c_int)() ) -> BOOL', 
    argNames=['None', 'None', ''],
)

USHORT = c_ushort 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:51
wglGetGammaTableI3D = platform.createBaseFunction(
    'wglGetGammaTableI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, c_int, POINTER(USHORT), POINTER(USHORT), POINTER(USHORT)],
    doc='wglGetGammaTableI3D( HDC(None), c_int(None), POINTER(USHORT)(), POINTER(USHORT)(), POINTER(USHORT)() ) -> BOOL', 
    argNames=['None', 'None', '', '', ''],
)

wglSetGammaTableI3D = platform.createBaseFunction(
    'wglSetGammaTableI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, c_int, POINTER(USHORT), POINTER(USHORT), POINTER(USHORT)],
    doc='wglSetGammaTableI3D( HDC(None), c_int(None), POINTER(USHORT)(), POINTER(USHORT)(), POINTER(USHORT)() ) -> BOOL', 
    argNames=['None', 'None', '', '', ''],
)

PFNWGLGETGAMMATABLEPARAMETERSI3DPROC = CFUNCTYPE(BOOL, HDC, c_int, POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:564
PFNWGLSETGAMMATABLEPARAMETERSI3DPROC = CFUNCTYPE(BOOL, HDC, c_int, POINTER(c_int)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:565
PFNWGLGETGAMMATABLEI3DPROC = CFUNCTYPE(BOOL, HDC, c_int, POINTER(USHORT), POINTER(USHORT), POINTER(USHORT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:566
PFNWGLSETGAMMATABLEI3DPROC = CFUNCTYPE(BOOL, HDC, c_int, POINTER(USHORT), POINTER(USHORT), POINTER(USHORT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:567
# I3D_genlock (http://developer.download.nvidia.com/opengl/includes/wglext.h:570)
WGL_I3D_genlock = constant.Constant( 'WGL_I3D_genlock', 1 )
wglEnableGenlockI3D = platform.createBaseFunction(
    'wglEnableGenlockI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC],
    doc='wglEnableGenlockI3D( HDC(None) ) -> BOOL', 
    argNames=['None'],
)

wglDisableGenlockI3D = platform.createBaseFunction(
    'wglDisableGenlockI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC],
    doc='wglDisableGenlockI3D( HDC(None) ) -> BOOL', 
    argNames=['None'],
)

wglIsEnabledGenlockI3D = platform.createBaseFunction(
    'wglIsEnabledGenlockI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(BOOL)],
    doc='wglIsEnabledGenlockI3D( HDC(None), POINTER(BOOL)() ) -> BOOL', 
    argNames=['None', ''],
)

wglGenlockSourceI3D = platform.createBaseFunction(
    'wglGenlockSourceI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, UINT],
    doc='wglGenlockSourceI3D( HDC(None), UINT(None) ) -> BOOL', 
    argNames=['None', 'None'],
)

wglGetGenlockSourceI3D = platform.createBaseFunction(
    'wglGetGenlockSourceI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(UINT)],
    doc='wglGetGenlockSourceI3D( HDC(None), POINTER(UINT)() ) -> BOOL', 
    argNames=['None', ''],
)

wglGenlockSourceEdgeI3D = platform.createBaseFunction(
    'wglGenlockSourceEdgeI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, UINT],
    doc='wglGenlockSourceEdgeI3D( HDC(None), UINT(None) ) -> BOOL', 
    argNames=['None', 'None'],
)

wglGetGenlockSourceEdgeI3D = platform.createBaseFunction(
    'wglGetGenlockSourceEdgeI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(UINT)],
    doc='wglGetGenlockSourceEdgeI3D( HDC(None), POINTER(UINT)() ) -> BOOL', 
    argNames=['None', ''],
)

wglGenlockSampleRateI3D = platform.createBaseFunction(
    'wglGenlockSampleRateI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, UINT],
    doc='wglGenlockSampleRateI3D( HDC(None), UINT(None) ) -> BOOL', 
    argNames=['None', 'None'],
)

wglGetGenlockSampleRateI3D = platform.createBaseFunction(
    'wglGetGenlockSampleRateI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(UINT)],
    doc='wglGetGenlockSampleRateI3D( HDC(None), POINTER(UINT)() ) -> BOOL', 
    argNames=['None', ''],
)

wglGenlockSourceDelayI3D = platform.createBaseFunction(
    'wglGenlockSourceDelayI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, UINT],
    doc='wglGenlockSourceDelayI3D( HDC(None), UINT(None) ) -> BOOL', 
    argNames=['None', 'None'],
)

wglGetGenlockSourceDelayI3D = platform.createBaseFunction(
    'wglGetGenlockSourceDelayI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(UINT)],
    doc='wglGetGenlockSourceDelayI3D( HDC(None), POINTER(UINT)() ) -> BOOL', 
    argNames=['None', ''],
)

wglQueryGenlockMaxSourceDelayI3D = platform.createBaseFunction(
    'wglQueryGenlockMaxSourceDelayI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(UINT), POINTER(UINT)],
    doc='wglQueryGenlockMaxSourceDelayI3D( HDC(None), POINTER(UINT)(), POINTER(UINT)() ) -> BOOL', 
    argNames=['None', '', ''],
)

PFNWGLENABLEGENLOCKI3DPROC = CFUNCTYPE(BOOL, HDC) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:586
PFNWGLDISABLEGENLOCKI3DPROC = CFUNCTYPE(BOOL, HDC) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:587
PFNWGLISENABLEDGENLOCKI3DPROC = CFUNCTYPE(BOOL, HDC, POINTER(BOOL)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:588
PFNWGLGENLOCKSOURCEI3DPROC = CFUNCTYPE(BOOL, HDC, UINT) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:589
PFNWGLGETGENLOCKSOURCEI3DPROC = CFUNCTYPE(BOOL, HDC, POINTER(UINT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:590
PFNWGLGENLOCKSOURCEEDGEI3DPROC = CFUNCTYPE(BOOL, HDC, UINT) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:591
PFNWGLGETGENLOCKSOURCEEDGEI3DPROC = CFUNCTYPE(BOOL, HDC, POINTER(UINT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:592
PFNWGLGENLOCKSAMPLERATEI3DPROC = CFUNCTYPE(BOOL, HDC, UINT) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:593
PFNWGLGETGENLOCKSAMPLERATEI3DPROC = CFUNCTYPE(BOOL, HDC, POINTER(UINT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:594
PFNWGLGENLOCKSOURCEDELAYI3DPROC = CFUNCTYPE(BOOL, HDC, UINT) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:595
PFNWGLGETGENLOCKSOURCEDELAYI3DPROC = CFUNCTYPE(BOOL, HDC, POINTER(UINT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:596
PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC = CFUNCTYPE(BOOL, HDC, POINTER(UINT), POINTER(UINT)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:597
# I3D_image_buffer (http://developer.download.nvidia.com/opengl/includes/wglext.h:600)
WGL_I3D_image_buffer = constant.Constant( 'WGL_I3D_image_buffer', 1 )
LPVOID = POINTER(None) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:47
wglCreateImageBufferI3D = platform.createBaseFunction(
    'wglCreateImageBufferI3D', dll=platform.GL, resultType=LPVOID, 
    argTypes=[HDC, DWORD, UINT],
    doc='wglCreateImageBufferI3D( HDC(None), DWORD(None), UINT(None) ) -> LPVOID', 
    argNames=['None', 'None', 'None'],
)

wglDestroyImageBufferI3D = platform.createBaseFunction(
    'wglDestroyImageBufferI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, LPVOID],
    doc='wglDestroyImageBufferI3D( HDC(None), LPVOID(None) ) -> BOOL', 
    argNames=['None', 'None'],
)

wglAssociateImageBufferEventsI3D = platform.createBaseFunction(
    'wglAssociateImageBufferEventsI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(HANDLE), POINTER(LPVOID), POINTER(DWORD), UINT],
    doc='wglAssociateImageBufferEventsI3D( HDC(None), POINTER(HANDLE)(), POINTER(LPVOID)(), POINTER(DWORD)(), UINT(None) ) -> BOOL', 
    argNames=['None', '', '', '', 'None'],
)

wglReleaseImageBufferEventsI3D = platform.createBaseFunction(
    'wglReleaseImageBufferEventsI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(LPVOID), UINT],
    doc='wglReleaseImageBufferEventsI3D( HDC(None), POINTER(LPVOID)(), UINT(None) ) -> BOOL', 
    argNames=['None', '', 'None'],
)

PFNWGLCREATEIMAGEBUFFERI3DPROC = CFUNCTYPE(LPVOID, HDC, DWORD, UINT) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:608
PFNWGLDESTROYIMAGEBUFFERI3DPROC = CFUNCTYPE(BOOL, HDC, LPVOID) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:609
PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC = CFUNCTYPE(BOOL, HDC, POINTER(HANDLE), POINTER(LPVOID), POINTER(DWORD), UINT) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:610
PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC = CFUNCTYPE(BOOL, HDC, POINTER(LPVOID), UINT) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:611
# I3D_swap_frame_lock (http://developer.download.nvidia.com/opengl/includes/wglext.h:614)
WGL_I3D_swap_frame_lock = constant.Constant( 'WGL_I3D_swap_frame_lock', 1 )
wglEnableFrameLockI3D = platform.createBaseFunction(
    'wglEnableFrameLockI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[],
    doc='wglEnableFrameLockI3D(  ) -> BOOL', 
    argNames=[],
)

wglDisableFrameLockI3D = platform.createBaseFunction(
    'wglDisableFrameLockI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[],
    doc='wglDisableFrameLockI3D(  ) -> BOOL', 
    argNames=[],
)

wglIsEnabledFrameLockI3D = platform.createBaseFunction(
    'wglIsEnabledFrameLockI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[POINTER(BOOL)],
    doc='wglIsEnabledFrameLockI3D( POINTER(BOOL)() ) -> BOOL', 
    argNames=[''],
)

wglQueryFrameLockMasterI3D = platform.createBaseFunction(
    'wglQueryFrameLockMasterI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[POINTER(BOOL)],
    doc='wglQueryFrameLockMasterI3D( POINTER(BOOL)() ) -> BOOL', 
    argNames=[''],
)

PFNWGLENABLEFRAMELOCKI3DPROC = CFUNCTYPE(BOOL) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:622
PFNWGLDISABLEFRAMELOCKI3DPROC = CFUNCTYPE(BOOL) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:623
PFNWGLISENABLEDFRAMELOCKI3DPROC = CFUNCTYPE(BOOL, POINTER(BOOL)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:624
PFNWGLQUERYFRAMELOCKMASTERI3DPROC = CFUNCTYPE(BOOL, POINTER(BOOL)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:625
# I3D_swap_frame_usage (http://developer.download.nvidia.com/opengl/includes/wglext.h:628)
WGL_I3D_swap_frame_usage = constant.Constant( 'WGL_I3D_swap_frame_usage', 1 )
wglGetFrameUsageI3D = platform.createBaseFunction(
    'wglGetFrameUsageI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[POINTER(c_float)],
    doc='wglGetFrameUsageI3D( POINTER(c_float)() ) -> BOOL', 
    argNames=[''],
)

wglBeginFrameTrackingI3D = platform.createBaseFunction(
    'wglBeginFrameTrackingI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[],
    doc='wglBeginFrameTrackingI3D(  ) -> BOOL', 
    argNames=[],
)

wglEndFrameTrackingI3D = platform.createBaseFunction(
    'wglEndFrameTrackingI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[],
    doc='wglEndFrameTrackingI3D(  ) -> BOOL', 
    argNames=[],
)

wglQueryFrameTrackingI3D = platform.createBaseFunction(
    'wglQueryFrameTrackingI3D', dll=platform.GL, resultType=BOOL, 
    argTypes=[POINTER(DWORD), POINTER(DWORD), POINTER(c_float)],
    doc='wglQueryFrameTrackingI3D( POINTER(DWORD)(), POINTER(DWORD)(), POINTER(c_float)() ) -> BOOL', 
    argNames=['', '', ''],
)

PFNWGLGETFRAMEUSAGEI3DPROC = CFUNCTYPE(BOOL, POINTER(c_float)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:636
PFNWGLBEGINFRAMETRACKINGI3DPROC = CFUNCTYPE(BOOL) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:637
PFNWGLENDFRAMETRACKINGI3DPROC = CFUNCTYPE(BOOL) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:638
PFNWGLQUERYFRAMETRACKINGI3DPROC = CFUNCTYPE(BOOL, POINTER(DWORD), POINTER(DWORD), POINTER(c_float)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:639
# ATI_pixel_format_float (http://developer.download.nvidia.com/opengl/includes/wglext.h:642)
WGL_ATI_pixel_format_float = constant.Constant( 'WGL_ATI_pixel_format_float', 1 )
# NV_render_depth_texture (http://developer.download.nvidia.com/opengl/includes/wglext.h:646)
WGL_NV_render_depth_texture = constant.Constant( 'WGL_NV_render_depth_texture', 1 )
# NV_render_texture_rectangle (http://developer.download.nvidia.com/opengl/includes/wglext.h:650)
WGL_NV_render_texture_rectangle = constant.Constant( 'WGL_NV_render_texture_rectangle', 1 )
# NV_float_buffer (http://developer.download.nvidia.com/opengl/includes/wglext.h:654)
WGL_NV_float_buffer = constant.Constant( 'WGL_NV_float_buffer', 1 )
# NV_swap_group (http://developer.download.nvidia.com/opengl/includes/wglext.h:658)
WGL_NV_swap_group = constant.Constant( 'WGL_NV_swap_group', 1 )
wglJoinSwapGroupNV = platform.createBaseFunction(
    'wglJoinSwapGroupNV', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, GLuint],
    doc='wglJoinSwapGroupNV( HDC(hDC), GLuint(group) ) -> BOOL', 
    argNames=['hDC', 'group'],
)

wglBindSwapBarrierNV = platform.createBaseFunction(
    'wglBindSwapBarrierNV', dll=platform.GL, resultType=BOOL, 
    argTypes=[GLuint, GLuint],
    doc='wglBindSwapBarrierNV( GLuint(group), GLuint(barrier) ) -> BOOL', 
    argNames=['group', 'barrier'],
)

wglQuerySwapGroupNV = platform.createBaseFunction(
    'wglQuerySwapGroupNV', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(GLuint), POINTER(GLuint)],
    doc='wglQuerySwapGroupNV( HDC(hDC), POINTER(GLuint)(group), POINTER(GLuint)(barrier) ) -> BOOL', 
    argNames=['hDC', 'group', 'barrier'],
)

wglQueryMaxSwapGroupsNV = platform.createBaseFunction(
    'wglQueryMaxSwapGroupsNV', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(GLuint), POINTER(GLuint)],
    doc='wglQueryMaxSwapGroupsNV( HDC(hDC), POINTER(GLuint)(maxGroups), POINTER(GLuint)(maxBarriers) ) -> BOOL', 
    argNames=['hDC', 'maxGroups', 'maxBarriers'],
)

wglQueryFrameCountNV = platform.createBaseFunction(
    'wglQueryFrameCountNV', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, POINTER(GLuint)],
    doc='wglQueryFrameCountNV( HDC(hDC), POINTER(GLuint)(count) ) -> BOOL', 
    argNames=['hDC', 'count'],
)

wglResetFrameCountNV = platform.createBaseFunction(
    'wglResetFrameCountNV', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC],
    doc='wglResetFrameCountNV( HDC(hDC) ) -> BOOL', 
    argNames=['hDC'],
)

PFNWGLJOINSWAPGROUPNVPROC = CFUNCTYPE(BOOL, HDC, GLuint) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:668
PFNWGLBINDSWAPBARRIERNVPROC = CFUNCTYPE(BOOL, GLuint, GLuint) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:669
PFNWGLQUERYSWAPGROUPNVPROC = CFUNCTYPE(BOOL, HDC, POINTER(GLuint), POINTER(GLuint)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:670
PFNWGLQUERYMAXSWAPGROUPSNVPROC = CFUNCTYPE(BOOL, HDC, POINTER(GLuint), POINTER(GLuint)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:671
PFNWGLQUERYFRAMECOUNTNVPROC = CFUNCTYPE(BOOL, HDC, POINTER(GLuint)) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:672
PFNWGLRESETFRAMECOUNTNVPROC = CFUNCTYPE(BOOL, HDC) 	# http://developer.download.nvidia.com/opengl/includes/wglext.h:673
# NV_gpu_affinity (http://developer.download.nvidia.com/opengl/includes/wglext.h:676)
WGL_NV_gpu_affinity = constant.Constant( 'WGL_NV_gpu_affinity', 1 )
wglEnumGpusNV = platform.createBaseFunction(
    'wglEnumGpusNV', dll=platform.GL, resultType=BOOL, 
    argTypes=[UINT, POINTER(HGPUNV)],
    doc='wglEnumGpusNV( UINT(iIndex), POINTER(HGPUNV)(hGpu) ) -> BOOL', 
    argNames=['iIndex', 'hGpu'],
)

wglEnumGpuDevicesNV = platform.createBaseFunction(
    'wglEnumGpuDevicesNV', dll=platform.GL, resultType=BOOL, 
    argTypes=[HGPUNV, UINT, PGPU_DEVICE],
    doc='wglEnumGpuDevicesNV( HGPUNV(hGpu), UINT(iIndex), PGPU_DEVICE(pGpuDevice) ) -> BOOL', 
    argNames=['hGpu', 'iIndex', 'pGpuDevice'],
)

wglCreateAffinityDCNV = platform.createBaseFunction(
    'wglCreateAffinityDCNV', dll=platform.GL, resultType=HDC, 
    argTypes=[POINTER(HGPUNV)],
    doc='wglCreateAffinityDCNV( POINTER(HGPUNV)(pGpuList) ) -> HDC', 
    argNames=['pGpuList'],
)

wglEnumGpusFromAffinityDCNV = platform.createBaseFunction(
    'wglEnumGpusFromAffinityDCNV', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC, UINT, POINTER(HGPUNV)],
    doc='wglEnumGpusFromAffinityDCNV( HDC(hAffinityDC), UINT(iIndex), POINTER(HGPUNV)(hGpu) ) -> BOOL', 
    argNames=['hAffinityDC', 'iIndex', 'hGpu'],
)

wglDeleteDCNV = platform.createBaseFunction(
    'wglDeleteDCNV', dll=platform.GL, resultType=BOOL, 
    argTypes=[HDC],
    doc='wglDeleteDCNV( HDC(hAffinityDC) ) -> BOOL', 
    argNames=['hAffinityDC'],
)


__all__ = ['GLAPI', 'WGL_WGLEXT_VERSION', 'WGL_FRONT_COLOR_BUFFER_BIT_ARB',
'WGL_BACK_COLOR_BUFFER_BIT_ARB', 'WGL_DEPTH_BUFFER_BIT_ARB',
'WGL_STENCIL_BUFFER_BIT_ARB', 'WGL_SAMPLE_BUFFERS_ARB', 'WGL_SAMPLES_ARB',
'WGL_NUMBER_PIXEL_FORMATS_ARB', 'WGL_DRAW_TO_WINDOW_ARB',
'WGL_DRAW_TO_BITMAP_ARB', 'WGL_ACCELERATION_ARB', 'WGL_NEED_PALETTE_ARB',
'WGL_NEED_SYSTEM_PALETTE_ARB', 'WGL_SWAP_LAYER_BUFFERS_ARB',
'WGL_SWAP_METHOD_ARB', 'WGL_NUMBER_OVERLAYS_ARB', 'WGL_NUMBER_UNDERLAYS_ARB',
'WGL_TRANSPARENT_ARB', 'WGL_TRANSPARENT_RED_VALUE_ARB',
'WGL_TRANSPARENT_GREEN_VALUE_ARB', 'WGL_TRANSPARENT_BLUE_VALUE_ARB',
'WGL_TRANSPARENT_ALPHA_VALUE_ARB', 'WGL_TRANSPARENT_INDEX_VALUE_ARB',
'WGL_SHARE_DEPTH_ARB', 'WGL_SHARE_STENCIL_ARB', 'WGL_SHARE_ACCUM_ARB',
'WGL_SUPPORT_GDI_ARB', 'WGL_SUPPORT_OPENGL_ARB', 'WGL_DOUBLE_BUFFER_ARB',
'WGL_STEREO_ARB', 'WGL_PIXEL_TYPE_ARB', 'WGL_COLOR_BITS_ARB',
'WGL_RED_BITS_ARB', 'WGL_RED_SHIFT_ARB', 'WGL_GREEN_BITS_ARB',
'WGL_GREEN_SHIFT_ARB', 'WGL_BLUE_BITS_ARB', 'WGL_BLUE_SHIFT_ARB',
'WGL_ALPHA_BITS_ARB', 'WGL_ALPHA_SHIFT_ARB', 'WGL_ACCUM_BITS_ARB',
'WGL_ACCUM_RED_BITS_ARB', 'WGL_ACCUM_GREEN_BITS_ARB',
'WGL_ACCUM_BLUE_BITS_ARB', 'WGL_ACCUM_ALPHA_BITS_ARB', 'WGL_DEPTH_BITS_ARB',
'WGL_STENCIL_BITS_ARB', 'WGL_AUX_BUFFERS_ARB', 'WGL_NO_ACCELERATION_ARB',
'WGL_GENERIC_ACCELERATION_ARB', 'WGL_FULL_ACCELERATION_ARB',
'WGL_SWAP_EXCHANGE_ARB', 'WGL_SWAP_COPY_ARB', 'WGL_SWAP_UNDEFINED_ARB',
'WGL_TYPE_RGBA_ARB', 'WGL_TYPE_COLORINDEX_ARB',
'ERROR_INVALID_PIXEL_TYPE_ARB', 'ERROR_INCOMPATIBLE_DEVICE_CONTEXTS_ARB',
'WGL_DRAW_TO_PBUFFER_ARB', 'WGL_MAX_PBUFFER_PIXELS_ARB',
'WGL_MAX_PBUFFER_WIDTH_ARB', 'WGL_MAX_PBUFFER_HEIGHT_ARB',
'WGL_PBUFFER_LARGEST_ARB', 'WGL_PBUFFER_WIDTH_ARB', 'WGL_PBUFFER_HEIGHT_ARB',
'WGL_PBUFFER_LOST_ARB', 'WGL_BIND_TO_TEXTURE_RGB_ARB',
'WGL_BIND_TO_TEXTURE_RGBA_ARB', 'WGL_TEXTURE_FORMAT_ARB',
'WGL_TEXTURE_TARGET_ARB', 'WGL_MIPMAP_TEXTURE_ARB', 'WGL_TEXTURE_RGB_ARB',
'WGL_TEXTURE_RGBA_ARB', 'WGL_NO_TEXTURE_ARB', 'WGL_TEXTURE_CUBE_MAP_ARB',
'WGL_TEXTURE_1D_ARB', 'WGL_TEXTURE_2D_ARB', 'WGL_MIPMAP_LEVEL_ARB',
'WGL_CUBE_MAP_FACE_ARB', 'WGL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB',
'WGL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB', 'WGL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB',
'WGL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB', 'WGL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB',
'WGL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB', 'WGL_FRONT_LEFT_ARB',
'WGL_FRONT_RIGHT_ARB', 'WGL_BACK_LEFT_ARB', 'WGL_BACK_RIGHT_ARB',
'WGL_AUX0_ARB', 'WGL_AUX1_ARB', 'WGL_AUX2_ARB', 'WGL_AUX3_ARB',
'WGL_AUX4_ARB', 'WGL_AUX5_ARB', 'WGL_AUX6_ARB', 'WGL_AUX7_ARB',
'WGL_AUX8_ARB', 'WGL_AUX9_ARB', 'WGL_TYPE_RGBA_FLOAT_ARB',
'ERROR_INVALID_PIXEL_TYPE_EXT', 'WGL_NUMBER_PIXEL_FORMATS_EXT',
'WGL_DRAW_TO_WINDOW_EXT', 'WGL_DRAW_TO_BITMAP_EXT', 'WGL_ACCELERATION_EXT',
'WGL_NEED_PALETTE_EXT', 'WGL_NEED_SYSTEM_PALETTE_EXT',
'WGL_SWAP_LAYER_BUFFERS_EXT', 'WGL_SWAP_METHOD_EXT',
'WGL_NUMBER_OVERLAYS_EXT', 'WGL_NUMBER_UNDERLAYS_EXT', 'WGL_TRANSPARENT_EXT',
'WGL_TRANSPARENT_VALUE_EXT', 'WGL_SHARE_DEPTH_EXT', 'WGL_SHARE_STENCIL_EXT',
'WGL_SHARE_ACCUM_EXT', 'WGL_SUPPORT_GDI_EXT', 'WGL_SUPPORT_OPENGL_EXT',
'WGL_DOUBLE_BUFFER_EXT', 'WGL_STEREO_EXT', 'WGL_PIXEL_TYPE_EXT',
'WGL_COLOR_BITS_EXT', 'WGL_RED_BITS_EXT', 'WGL_RED_SHIFT_EXT',
'WGL_GREEN_BITS_EXT', 'WGL_GREEN_SHIFT_EXT', 'WGL_BLUE_BITS_EXT',
'WGL_BLUE_SHIFT_EXT', 'WGL_ALPHA_BITS_EXT', 'WGL_ALPHA_SHIFT_EXT',
'WGL_ACCUM_BITS_EXT', 'WGL_ACCUM_RED_BITS_EXT', 'WGL_ACCUM_GREEN_BITS_EXT',
'WGL_ACCUM_BLUE_BITS_EXT', 'WGL_ACCUM_ALPHA_BITS_EXT', 'WGL_DEPTH_BITS_EXT',
'WGL_STENCIL_BITS_EXT', 'WGL_AUX_BUFFERS_EXT', 'WGL_NO_ACCELERATION_EXT',
'WGL_GENERIC_ACCELERATION_EXT', 'WGL_FULL_ACCELERATION_EXT',
'WGL_SWAP_EXCHANGE_EXT', 'WGL_SWAP_COPY_EXT', 'WGL_SWAP_UNDEFINED_EXT',
'WGL_TYPE_RGBA_EXT', 'WGL_TYPE_COLORINDEX_EXT', 'WGL_DRAW_TO_PBUFFER_EXT',
'WGL_MAX_PBUFFER_PIXELS_EXT', 'WGL_MAX_PBUFFER_WIDTH_EXT',
'WGL_MAX_PBUFFER_HEIGHT_EXT', 'WGL_OPTIMAL_PBUFFER_WIDTH_EXT',
'WGL_OPTIMAL_PBUFFER_HEIGHT_EXT', 'WGL_PBUFFER_LARGEST_EXT',
'WGL_PBUFFER_WIDTH_EXT', 'WGL_PBUFFER_HEIGHT_EXT', 'WGL_DEPTH_FLOAT_EXT',
'WGL_SAMPLE_BUFFERS_3DFX', 'WGL_SAMPLES_3DFX', 'WGL_SAMPLE_BUFFERS_EXT',
'WGL_SAMPLES_EXT', 'WGL_DIGITAL_VIDEO_CURSOR_ALPHA_FRAMEBUFFER_I3D',
'WGL_DIGITAL_VIDEO_CURSOR_ALPHA_VALUE_I3D',
'WGL_DIGITAL_VIDEO_CURSOR_INCLUDED_I3D',
'WGL_DIGITAL_VIDEO_GAMMA_CORRECTED_I3D', 'WGL_GAMMA_TABLE_SIZE_I3D',
'WGL_GAMMA_EXCLUDE_DESKTOP_I3D', 'WGL_GENLOCK_SOURCE_MULTIVIEW_I3D',
'WGL_GENLOCK_SOURCE_EXTENAL_SYNC_I3D', 'WGL_GENLOCK_SOURCE_EXTENAL_FIELD_I3D',
'WGL_GENLOCK_SOURCE_EXTENAL_TTL_I3D', 'WGL_GENLOCK_SOURCE_DIGITAL_SYNC_I3D',
'WGL_GENLOCK_SOURCE_DIGITAL_FIELD_I3D', 'WGL_GENLOCK_SOURCE_EDGE_FALLING_I3D',
'WGL_GENLOCK_SOURCE_EDGE_RISING_I3D', 'WGL_GENLOCK_SOURCE_EDGE_BOTH_I3D',
'WGL_IMAGE_BUFFER_MIN_ACCESS_I3D', 'WGL_IMAGE_BUFFER_LOCK_I3D',
'WGL_BIND_TO_TEXTURE_DEPTH_NV', 'WGL_BIND_TO_TEXTURE_RECTANGLE_DEPTH_NV',
'WGL_DEPTH_TEXTURE_FORMAT_NV', 'WGL_TEXTURE_DEPTH_COMPONENT_NV',
'WGL_DEPTH_COMPONENT_NV', 'WGL_BIND_TO_TEXTURE_RECTANGLE_RGB_NV',
'WGL_BIND_TO_TEXTURE_RECTANGLE_RGBA_NV', 'WGL_TEXTURE_RECTANGLE_NV',
'WGL_TYPE_RGBA_FLOAT_ATI', 'WGL_RGBA_FLOAT_MODE_ATI',
'WGL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI', 'WGL_FLOAT_COMPONENTS_NV',
'WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_R_NV',
'WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RG_NV',
'WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGB_NV',
'WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGBA_NV', 'WGL_TEXTURE_FLOAT_R_NV',
'WGL_TEXTURE_FLOAT_RG_NV', 'WGL_TEXTURE_FLOAT_RGB_NV',
'WGL_TEXTURE_FLOAT_RGBA_NV', 'WGL_ERROR_INCOMPATIBLE_AFFINITY_MASKS_NV',
'WGL_ERROR_MISSING_AFFINITY_MASK_NV', 'HPBUFFERARB', 'HPBUFFEREXT', 'HGPUNV',
'GPU_DEVICE', 'PGPU_DEVICE', 'WGL_ARB_buffer_region',
'wglCreateBufferRegionARB', 'wglDeleteBufferRegionARB',
'wglSaveBufferRegionARB', 'wglRestoreBufferRegionARB',
'PFNWGLCREATEBUFFERREGIONARBPROC', 'PFNWGLDELETEBUFFERREGIONARBPROC',
'PFNWGLSAVEBUFFERREGIONARBPROC', 'PFNWGLRESTOREBUFFERREGIONARBPROC',
'WGL_ARB_multisample', 'WGL_ARB_extensions_string',
'wglGetExtensionsStringARB', 'PFNWGLGETEXTENSIONSSTRINGARBPROC',
'WGL_ARB_pixel_format', 'wglGetPixelFormatAttribivARB',
'wglGetPixelFormatAttribfvARB', 'wglChoosePixelFormatARB',
'PFNWGLGETPIXELFORMATATTRIBIVARBPROC', 'PFNWGLGETPIXELFORMATATTRIBFVARBPROC',
'PFNWGLCHOOSEPIXELFORMATARBPROC', 'WGL_ARB_make_current_read',
'wglMakeContextCurrentARB', 'wglGetCurrentReadDCARB',
'PFNWGLMAKECONTEXTCURRENTARBPROC', 'PFNWGLGETCURRENTREADDCARBPROC',
'WGL_ARB_pbuffer', 'wglCreatePbufferARB', 'wglGetPbufferDCARB',
'wglReleasePbufferDCARB', 'wglDestroyPbufferARB', 'wglQueryPbufferARB',
'PFNWGLCREATEPBUFFERARBPROC', 'PFNWGLGETPBUFFERDCARBPROC',
'PFNWGLRELEASEPBUFFERDCARBPROC', 'PFNWGLDESTROYPBUFFERARBPROC',
'PFNWGLQUERYPBUFFERARBPROC', 'WGL_ARB_render_texture', 'wglBindTexImageARB',
'wglReleaseTexImageARB', 'wglSetPbufferAttribARB',
'PFNWGLBINDTEXIMAGEARBPROC', 'PFNWGLRELEASETEXIMAGEARBPROC',
'PFNWGLSETPBUFFERATTRIBARBPROC', 'WGL_ARB_pixel_format_float',
'WGL_EXT_display_color_table', 'wglCreateDisplayColorTableEXT',
'wglLoadDisplayColorTableEXT', 'wglBindDisplayColorTableEXT',
'wglDestroyDisplayColorTableEXT', 'PFNWGLCREATEDISPLAYCOLORTABLEEXTPROC',
'PFNWGLLOADDISPLAYCOLORTABLEEXTPROC', 'PFNWGLBINDDISPLAYCOLORTABLEEXTPROC',
'PFNWGLDESTROYDISPLAYCOLORTABLEEXTPROC', 'WGL_EXT_extensions_string',
'wglGetExtensionsStringEXT', 'PFNWGLGETEXTENSIONSSTRINGEXTPROC',
'WGL_EXT_make_current_read', 'wglMakeContextCurrentEXT',
'wglGetCurrentReadDCEXT', 'PFNWGLMAKECONTEXTCURRENTEXTPROC',
'PFNWGLGETCURRENTREADDCEXTPROC', 'WGL_EXT_pbuffer', 'wglCreatePbufferEXT',
'wglGetPbufferDCEXT', 'wglReleasePbufferDCEXT', 'wglDestroyPbufferEXT',
'wglQueryPbufferEXT', 'PFNWGLCREATEPBUFFEREXTPROC',
'PFNWGLGETPBUFFERDCEXTPROC', 'PFNWGLRELEASEPBUFFERDCEXTPROC',
'PFNWGLDESTROYPBUFFEREXTPROC', 'PFNWGLQUERYPBUFFEREXTPROC',
'WGL_EXT_pixel_format', 'wglGetPixelFormatAttribivEXT',
'wglGetPixelFormatAttribfvEXT', 'wglChoosePixelFormatEXT',
'PFNWGLGETPIXELFORMATATTRIBIVEXTPROC', 'PFNWGLGETPIXELFORMATATTRIBFVEXTPROC',
'PFNWGLCHOOSEPIXELFORMATEXTPROC', 'WGL_EXT_swap_control',
'wglSwapIntervalEXT', 'wglGetSwapIntervalEXT', 'PFNWGLSWAPINTERVALEXTPROC',
'PFNWGLGETSWAPINTERVALEXTPROC', 'WGL_EXT_depth_float',
'WGL_NV_vertex_array_range', 'wglAllocateMemoryNV', 'wglFreeMemoryNV',
'PFNWGLALLOCATEMEMORYNVPROC', 'PFNWGLFREEMEMORYNVPROC',
'WGL_3DFX_multisample', 'WGL_EXT_multisample', 'WGL_OML_sync_control',
'wglGetSyncValuesOML', 'wglGetMscRateOML', 'wglSwapBuffersMscOML',
'wglSwapLayerBuffersMscOML', 'wglWaitForMscOML', 'wglWaitForSbcOML',
'PFNWGLGETSYNCVALUESOMLPROC', 'PFNWGLGETMSCRATEOMLPROC',
'PFNWGLSWAPBUFFERSMSCOMLPROC', 'PFNWGLSWAPLAYERBUFFERSMSCOMLPROC',
'PFNWGLWAITFORMSCOMLPROC', 'PFNWGLWAITFORSBCOMLPROC',
'WGL_I3D_digital_video_control', 'wglGetDigitalVideoParametersI3D',
'wglSetDigitalVideoParametersI3D', 'PFNWGLGETDIGITALVIDEOPARAMETERSI3DPROC',
'PFNWGLSETDIGITALVIDEOPARAMETERSI3DPROC', 'WGL_I3D_gamma',
'wglGetGammaTableParametersI3D', 'wglSetGammaTableParametersI3D',
'wglGetGammaTableI3D', 'wglSetGammaTableI3D',
'PFNWGLGETGAMMATABLEPARAMETERSI3DPROC',
'PFNWGLSETGAMMATABLEPARAMETERSI3DPROC', 'PFNWGLGETGAMMATABLEI3DPROC',
'PFNWGLSETGAMMATABLEI3DPROC', 'WGL_I3D_genlock', 'wglEnableGenlockI3D',
'wglDisableGenlockI3D', 'wglIsEnabledGenlockI3D', 'wglGenlockSourceI3D',
'wglGetGenlockSourceI3D', 'wglGenlockSourceEdgeI3D',
'wglGetGenlockSourceEdgeI3D', 'wglGenlockSampleRateI3D',
'wglGetGenlockSampleRateI3D', 'wglGenlockSourceDelayI3D',
'wglGetGenlockSourceDelayI3D', 'wglQueryGenlockMaxSourceDelayI3D',
'PFNWGLENABLEGENLOCKI3DPROC', 'PFNWGLDISABLEGENLOCKI3DPROC',
'PFNWGLISENABLEDGENLOCKI3DPROC', 'PFNWGLGENLOCKSOURCEI3DPROC',
'PFNWGLGETGENLOCKSOURCEI3DPROC', 'PFNWGLGENLOCKSOURCEEDGEI3DPROC',
'PFNWGLGETGENLOCKSOURCEEDGEI3DPROC', 'PFNWGLGENLOCKSAMPLERATEI3DPROC',
'PFNWGLGETGENLOCKSAMPLERATEI3DPROC', 'PFNWGLGENLOCKSOURCEDELAYI3DPROC',
'PFNWGLGETGENLOCKSOURCEDELAYI3DPROC',
'PFNWGLQUERYGENLOCKMAXSOURCEDELAYI3DPROC', 'WGL_I3D_image_buffer',
'wglCreateImageBufferI3D', 'wglDestroyImageBufferI3D',
'wglAssociateImageBufferEventsI3D', 'wglReleaseImageBufferEventsI3D',
'PFNWGLCREATEIMAGEBUFFERI3DPROC', 'PFNWGLDESTROYIMAGEBUFFERI3DPROC',
'PFNWGLASSOCIATEIMAGEBUFFEREVENTSI3DPROC',
'PFNWGLRELEASEIMAGEBUFFEREVENTSI3DPROC', 'WGL_I3D_swap_frame_lock',
'wglEnableFrameLockI3D', 'wglDisableFrameLockI3D', 'wglIsEnabledFrameLockI3D',
'wglQueryFrameLockMasterI3D', 'PFNWGLENABLEFRAMELOCKI3DPROC',
'PFNWGLDISABLEFRAMELOCKI3DPROC', 'PFNWGLISENABLEDFRAMELOCKI3DPROC',
'PFNWGLQUERYFRAMELOCKMASTERI3DPROC', 'WGL_I3D_swap_frame_usage',
'wglGetFrameUsageI3D', 'wglBeginFrameTrackingI3D', 'wglEndFrameTrackingI3D',
'wglQueryFrameTrackingI3D', 'PFNWGLGETFRAMEUSAGEI3DPROC',
'PFNWGLBEGINFRAMETRACKINGI3DPROC', 'PFNWGLENDFRAMETRACKINGI3DPROC',
'PFNWGLQUERYFRAMETRACKINGI3DPROC', 'WGL_ATI_pixel_format_float',
'WGL_NV_render_depth_texture', 'WGL_NV_render_texture_rectangle',
'WGL_NV_float_buffer', 'WGL_NV_swap_group', 'wglJoinSwapGroupNV',
'wglBindSwapBarrierNV', 'wglQuerySwapGroupNV', 'wglQueryMaxSwapGroupsNV',
'wglQueryFrameCountNV', 'wglResetFrameCountNV', 'PFNWGLJOINSWAPGROUPNVPROC',
'PFNWGLBINDSWAPBARRIERNVPROC', 'PFNWGLQUERYSWAPGROUPNVPROC',
'PFNWGLQUERYMAXSWAPGROUPSNVPROC', 'PFNWGLQUERYFRAMECOUNTNVPROC',
'PFNWGLRESETFRAMECOUNTNVPROC', 'WGL_NV_gpu_affinity', 'wglEnumGpusNV',
'wglEnumGpuDevicesNV', 'wglCreateAffinityDCNV', 'wglEnumGpusFromAffinityDCNV',
'wglDeleteDCNV']
# END GENERATED CONTENT (do not edit above this line)




'''OpenGL extension SGIS.generate_mipmap

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_generate_mipmap'
_DEPRECATED = False
GL_GENERATE_MIPMAP_SGIS = constant.Constant( 'GL_GENERATE_MIPMAP_SGIS', 0x8191 )
GL_GENERATE_MIPMAP_HINT_SGIS = constant.Constant( 'GL_GENERATE_MIPMAP_HINT_SGIS', 0x8192 )
glget.addGLGetConstant( GL_GENERATE_MIPMAP_HINT_SGIS, (1,) )


def glInitGenerateMipmapSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.draw_buffers2

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_draw_buffers2'
_DEPRECATED = False

glColorMaskIndexedEXT = platform.createExtensionFunction( 
'glColorMaskIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLboolean,constants.GLboolean,constants.GLboolean,constants.GLboolean,),
doc='glColorMaskIndexedEXT(GLuint(index), GLboolean(r), GLboolean(g), GLboolean(b), GLboolean(a)) -> None',
argNames=('index','r','g','b','a',),
deprecated=_DEPRECATED,
)

glGetBooleanIndexedvEXT = platform.createExtensionFunction( 
'glGetBooleanIndexedvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLbooleanArray,),
doc='glGetBooleanIndexedvEXT(GLenum(target), GLuint(index), GLbooleanArray(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glGetIntegerIndexedvEXT = platform.createExtensionFunction( 
'glGetIntegerIndexedvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glGetIntegerIndexedvEXT(GLenum(target), GLuint(index), GLintArray(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glEnableIndexedEXT = platform.createExtensionFunction( 
'glEnableIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glEnableIndexedEXT(GLenum(target), GLuint(index)) -> None',
argNames=('target','index',),
deprecated=_DEPRECATED,
)

glDisableIndexedEXT = platform.createExtensionFunction( 
'glDisableIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glDisableIndexedEXT(GLenum(target), GLuint(index)) -> None',
argNames=('target','index',),
deprecated=_DEPRECATED,
)

glIsEnabledIndexedEXT = platform.createExtensionFunction( 
'glIsEnabledIndexedEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glIsEnabledIndexedEXT(GLenum(target), GLuint(index)) -> constants.GLboolean',
argNames=('target','index',),
deprecated=_DEPRECATED,
)


def glInitDrawBuffers2EXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ATI.element_array

This module customises the behaviour of the 
OpenGL.raw.GL.ATI.element_array to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism for an application to create
	an array of index data for use in specifying geometric primitives.
	
	This extension is most useful when used in conjunction with the
	ATI_vertex_array_object extension. ATI_vertex_array_object
	provides an interface for storing vertex array data in persistent,
	hardware-addressable memory. In cases where large amounts of
	vertex data are in use, the index data used to construct
	primitives (typically as passed to the GL through DrawElements)
	can impose a significant bandwidth burden. ATI_element_array
	allows the application to specify independent arrays of elements,
	which can then be cached using ATI_vertex_array_object.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ATI/element_array.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ATI.element_array import *
### END AUTOGENERATED SECTION


'''OpenGL extension IBM.multimode_draw_arrays

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_IBM_multimode_draw_arrays'
_DEPRECATED = False

glMultiModeDrawArraysIBM = platform.createExtensionFunction( 
'glMultiModeDrawArraysIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLintArray,arrays.GLsizeiArray,constants.GLsizei,constants.GLint,),
doc='glMultiModeDrawArraysIBM(GLuintArray(mode), GLintArray(first), GLsizeiArray(count), GLsizei(primcount), GLint(modestride)) -> None',
argNames=('mode','first','count','primcount','modestride',),
deprecated=_DEPRECATED,
)

glMultiModeDrawElementsIBM = platform.createExtensionFunction( 
'glMultiModeDrawElementsIBM',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLuintArray,arrays.GLsizeiArray,constants.GLenum,ctypes.POINTER(ctypes.c_void_p),constants.GLsizei,constants.GLint,),
doc='glMultiModeDrawElementsIBM(GLuintArray(mode), GLsizeiArray(count), GLenum(type), POINTER(ctypes.c_void_p)(indices), GLsizei(primcount), GLint(modestride)) -> None',
argNames=('mode','count','type','indices','primcount','modestride',),
deprecated=_DEPRECATED,
)


def glInitMultimodeDrawArraysIBM():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
